//line parser.y:2
package main

import __yyfmt__ "fmt"

//line parser.y:2
import (
	"bytes"
	"fmt"
	"io"
	"os"
)

type node struct {
	name       string
	children   []node
	attributes map[string]string
}

func (n node) String() string {
	buf := new(bytes.Buffer)
	n.print(buf, " ")
	return buf.String()
}

func (n node) print(out io.Writer, indent string) {
	if len(n.attributes) > 0 {
		fmt.Fprintf(out, "\n%v%v %s", indent, n.name, n.attributes)
	} else {
		fmt.Fprintf(out, "\n%v%v", indent, n.name)
	}
	for _, nn := range n.children {
		nn.print(out, indent+"  ")
	}
}

func Node(name string) node {
	return node{name: name, attributes: make(map[string]string)}
}

func (n node) append(nn ...node) node {
	n.children = append(n.children, nn...)
	return n
}

func (n node) attribute(key string, value string) node {
	n.attributes[key] = value
	return n
}

//line parser.y:50
type yySymType struct {
	yys   int
	node  node
	token string
	value string
}

const T_INCLUDE = 57346
const T_INCLUDE_ONCE = 57347
const T_EVAL = 57348
const T_REQUIRE = 57349
const T_REQUIRE_ONCE = 57350
const T_LOGICAL_OR = 57351
const T_LOGICAL_XOR = 57352
const T_LOGICAL_AND = 57353
const T_PRINT = 57354
const T_YIELD = 57355
const T_DOUBLE_ARROW = 57356
const T_YIELD_FROM = 57357
const T_PLUS_EQUAL = 57358
const T_MINUS_EQUAL = 57359
const T_MUL_EQUAL = 57360
const T_DIV_EQUAL = 57361
const T_CONCAT_EQUAL = 57362
const T_MOD_EQUAL = 57363
const T_AND_EQUAL = 57364
const T_OR_EQUAL = 57365
const T_XOR_EQUAL = 57366
const T_SL_EQUAL = 57367
const T_SR_EQUAL = 57368
const T_POW_EQUAL = 57369
const T_COALESCE = 57370
const T_BOOLEAN_OR = 57371
const T_BOOLEAN_AND = 57372
const T_IS_EQUAL = 57373
const T_IS_NOT_EQUAL = 57374
const T_IS_IDENTICAL = 57375
const T_IS_NOT_IDENTICAL = 57376
const T_SPACESHIP = 57377
const T_IS_SMALLER_OR_EQUAL = 57378
const T_IS_GREATER_OR_EQUAL = 57379
const T_SL = 57380
const T_SR = 57381
const T_INSTANCEOF = 57382
const T_INC = 57383
const T_DEC = 57384
const T_INT_CAST = 57385
const T_DOUBLE_CAST = 57386
const T_STRING_CAST = 57387
const T_ARRAY_CAST = 57388
const T_OBJECT_CAST = 57389
const T_BOOL_CAST = 57390
const T_UNSET_CAST = 57391
const T_POW = 57392
const T_NEW = 57393
const T_CLONE = 57394
const T_NOELSE = 57395
const T_ELSEIF = 57396
const T_ELSE = 57397
const T_ENDIF = 57398
const T_STATIC = 57399
const T_ABSTRACT = 57400
const T_FINAL = 57401
const T_PRIVATE = 57402
const T_PROTECTED = 57403
const T_PUBLIC = 57404
const T_EXIT = 57405
const T_IF = 57406
const T_LNUMBER = 57407
const T_DNUMBER = 57408
const T_STRING = 57409
const T_STRING_VARNAME = 57410
const T_VARIABLE = 57411
const T_NUM_STRING = 57412
const T_INLINE_HTML = 57413
const T_CHARACTER = 57414
const T_BAD_CHARACTER = 57415
const T_ENCAPSED_AND_WHITESPACE = 57416
const T_CONSTANT_ENCAPSED_STRING = 57417
const T_ECHO = 57418
const T_DO = 57419
const T_WHILE = 57420
const T_ENDWHILE = 57421
const T_FOR = 57422
const T_ENDFOR = 57423
const T_FOREACH = 57424
const T_ENDFOREACH = 57425
const T_DECLARE = 57426
const T_ENDDECLARE = 57427
const T_AS = 57428
const T_SWITCH = 57429
const T_ENDSWITCH = 57430
const T_CASE = 57431
const T_DEFAULT = 57432
const T_BREAK = 57433
const T_CONTINUE = 57434
const T_GOTO = 57435
const T_FUNCTION = 57436
const T_CONST = 57437
const T_RETURN = 57438
const T_TRY = 57439
const T_CATCH = 57440
const T_FINALLY = 57441
const T_THROW = 57442
const T_USE = 57443
const T_INSTEADOF = 57444
const T_GLOBAL = 57445
const T_VAR = 57446
const T_UNSET = 57447
const T_ISSET = 57448
const T_EMPTY = 57449
const T_HALT_COMPILER = 57450
const T_CLASS = 57451
const T_TRAIT = 57452
const T_INTERFACE = 57453
const T_EXTENDS = 57454
const T_IMPLEMENTS = 57455
const T_OBJECT_OPERATOR = 57456
const T_LIST = 57457
const T_ARRAY = 57458
const T_CALLABLE = 57459
const T_CLASS_C = 57460
const T_TRAIT_C = 57461
const T_METHOD_C = 57462
const T_FUNC_C = 57463
const T_LINE = 57464
const T_FILE = 57465
const T_COMMENT = 57466
const T_DOC_COMMENT = 57467
const T_OPEN_TAG = 57468
const T_OPEN_TAG_WITH_ECHO = 57469
const T_CLOSE_TAG = 57470
const T_WHITESPACE = 57471
const T_START_HEREDOC = 57472
const T_END_HEREDOC = 57473
const T_DOLLAR_OPEN_CURLY_BRACES = 57474
const T_CURLY_OPEN = 57475
const T_PAAMAYIM_NEKUDOTAYIM = 57476
const T_NAMESPACE = 57477
const T_NS_C = 57478
const T_DIR = 57479
const T_NS_SEPARATOR = 57480
const T_ELLIPSIS = 57481

var yyToknames = [...]string{
	"$end",
	"error",
	"$unk",
	"T_INCLUDE",
	"T_INCLUDE_ONCE",
	"T_EVAL",
	"T_REQUIRE",
	"T_REQUIRE_ONCE",
	"','",
	"T_LOGICAL_OR",
	"T_LOGICAL_XOR",
	"T_LOGICAL_AND",
	"T_PRINT",
	"T_YIELD",
	"T_DOUBLE_ARROW",
	"T_YIELD_FROM",
	"'='",
	"T_PLUS_EQUAL",
	"T_MINUS_EQUAL",
	"T_MUL_EQUAL",
	"T_DIV_EQUAL",
	"T_CONCAT_EQUAL",
	"T_MOD_EQUAL",
	"T_AND_EQUAL",
	"T_OR_EQUAL",
	"T_XOR_EQUAL",
	"T_SL_EQUAL",
	"T_SR_EQUAL",
	"T_POW_EQUAL",
	"'?'",
	"':'",
	"T_COALESCE",
	"T_BOOLEAN_OR",
	"T_BOOLEAN_AND",
	"'|'",
	"'^'",
	"'&'",
	"T_IS_EQUAL",
	"T_IS_NOT_EQUAL",
	"T_IS_IDENTICAL",
	"T_IS_NOT_IDENTICAL",
	"T_SPACESHIP",
	"'<'",
	"T_IS_SMALLER_OR_EQUAL",
	"'>'",
	"T_IS_GREATER_OR_EQUAL",
	"T_SL",
	"T_SR",
	"'+'",
	"'-'",
	"'.'",
	"'*'",
	"'/'",
	"'%'",
	"'!'",
	"T_INSTANCEOF",
	"'~'",
	"T_INC",
	"T_DEC",
	"T_INT_CAST",
	"T_DOUBLE_CAST",
	"T_STRING_CAST",
	"T_ARRAY_CAST",
	"T_OBJECT_CAST",
	"T_BOOL_CAST",
	"T_UNSET_CAST",
	"'@'",
	"T_POW",
	"'['",
	"T_NEW",
	"T_CLONE",
	"T_NOELSE",
	"T_ELSEIF",
	"T_ELSE",
	"T_ENDIF",
	"T_STATIC",
	"T_ABSTRACT",
	"T_FINAL",
	"T_PRIVATE",
	"T_PROTECTED",
	"T_PUBLIC",
	"T_EXIT",
	"T_IF",
	"T_LNUMBER",
	"T_DNUMBER",
	"T_STRING",
	"T_STRING_VARNAME",
	"T_VARIABLE",
	"T_NUM_STRING",
	"T_INLINE_HTML",
	"T_CHARACTER",
	"T_BAD_CHARACTER",
	"T_ENCAPSED_AND_WHITESPACE",
	"T_CONSTANT_ENCAPSED_STRING",
	"T_ECHO",
	"T_DO",
	"T_WHILE",
	"T_ENDWHILE",
	"T_FOR",
	"T_ENDFOR",
	"T_FOREACH",
	"T_ENDFOREACH",
	"T_DECLARE",
	"T_ENDDECLARE",
	"T_AS",
	"T_SWITCH",
	"T_ENDSWITCH",
	"T_CASE",
	"T_DEFAULT",
	"T_BREAK",
	"T_CONTINUE",
	"T_GOTO",
	"T_FUNCTION",
	"T_CONST",
	"T_RETURN",
	"T_TRY",
	"T_CATCH",
	"T_FINALLY",
	"T_THROW",
	"T_USE",
	"T_INSTEADOF",
	"T_GLOBAL",
	"T_VAR",
	"T_UNSET",
	"T_ISSET",
	"T_EMPTY",
	"T_HALT_COMPILER",
	"T_CLASS",
	"T_TRAIT",
	"T_INTERFACE",
	"T_EXTENDS",
	"T_IMPLEMENTS",
	"T_OBJECT_OPERATOR",
	"T_LIST",
	"T_ARRAY",
	"T_CALLABLE",
	"T_CLASS_C",
	"T_TRAIT_C",
	"T_METHOD_C",
	"T_FUNC_C",
	"T_LINE",
	"T_FILE",
	"T_COMMENT",
	"T_DOC_COMMENT",
	"T_OPEN_TAG",
	"T_OPEN_TAG_WITH_ECHO",
	"T_CLOSE_TAG",
	"T_WHITESPACE",
	"T_START_HEREDOC",
	"T_END_HEREDOC",
	"T_DOLLAR_OPEN_CURLY_BRACES",
	"T_CURLY_OPEN",
	"T_PAAMAYIM_NEKUDOTAYIM",
	"T_NAMESPACE",
	"T_NS_C",
	"T_DIR",
	"T_NS_SEPARATOR",
	"T_ELLIPSIS",
	"'('",
	"')'",
	"';'",
	"'{'",
	"'}'",
	"']'",
	"'`'",
	"'\"'",
	"'$'",
}
var yyStatenames = [...]string{}

const yyEofCode = 1
const yyErrCode = 2
const yyInitialStackSize = 16

//line parser.y:1286
const src = `<?php
$a = static function($a) use ($b) {

};
`

func main() {
	yyDebug = 0
	yyErrorVerbose = true
	l := newLexer(bytes.NewBufferString(src), os.Stdout, "file.name")
	yyParse(l)
}

//line yacctab:1
var yyExca = [...]int{
	-1, 1,
	1, -1,
	-2, 0,
	-1, 43,
	69, 417,
	133, 417,
	153, 417,
	162, 417,
	-2, 412,
	-1, 47,
	159, 420,
	-2, 429,
	-1, 81,
	69, 419,
	133, 419,
	153, 419,
	159, 422,
	162, 419,
	-2, 407,
	-1, 104,
	153, 380,
	-2, 409,
	-1, 219,
	69, 417,
	133, 417,
	153, 417,
	162, 417,
	-2, 309,
	-1, 222,
	159, 422,
	-2, 419,
	-1, 224,
	69, 417,
	133, 417,
	153, 417,
	162, 417,
	-2, 311,
	-1, 349,
	38, 0,
	39, 0,
	40, 0,
	41, 0,
	42, 0,
	-2, 333,
	-1, 350,
	38, 0,
	39, 0,
	40, 0,
	41, 0,
	42, 0,
	-2, 334,
	-1, 351,
	38, 0,
	39, 0,
	40, 0,
	41, 0,
	42, 0,
	-2, 335,
	-1, 352,
	38, 0,
	39, 0,
	40, 0,
	41, 0,
	42, 0,
	-2, 336,
	-1, 353,
	38, 0,
	39, 0,
	40, 0,
	41, 0,
	42, 0,
	-2, 337,
	-1, 354,
	43, 0,
	44, 0,
	45, 0,
	46, 0,
	-2, 338,
	-1, 355,
	43, 0,
	44, 0,
	45, 0,
	46, 0,
	-2, 339,
	-1, 356,
	43, 0,
	44, 0,
	45, 0,
	46, 0,
	-2, 340,
	-1, 357,
	43, 0,
	44, 0,
	45, 0,
	46, 0,
	-2, 341,
	-1, 364,
	9, 161,
	160, 161,
	-2, 417,
	-1, 371,
	160, 211,
	-2, 216,
	-1, 405,
	69, 418,
	133, 418,
	153, 418,
	159, 421,
	162, 418,
	-2, 343,
	-1, 419,
	159, 443,
	-2, 410,
	-1, 420,
	159, 445,
	-2, 435,
	-1, 499,
	159, 443,
	-2, 411,
	-1, 500,
	159, 445,
	-2, 436,
	-1, 527,
	9, 457,
	160, 457,
	164, 457,
	-2, 417,
	-1, 553,
	160, 211,
	-2, 216,
	-1, 563,
	160, 211,
	-2, 216,
	-1, 591,
	159, 421,
	-2, 418,
	-1, 651,
	15, 181,
	160, 181,
	-2, 417,
	-1, 673,
	88, 263,
	-2, 266,
	-1, 701,
	9, 456,
	160, 456,
	164, 456,
	-2, 417,
	-1, 723,
	15, 182,
	160, 182,
	-2, 417,
	-1, 775,
	15, 184,
	160, 184,
	-2, 391,
	-1, 846,
	105, 76,
	-2, 80,
	-1, 869,
	160, 211,
	-2, 216,
}

const yyPrivate = 57344

const yyLast = 7420

var yyAct = [...]int{

	27, 128, 779, 791, 580, 675, 424, 564, 825, 838,
	790, 770, 807, 739, 104, 124, 568, 578, 650, 632,
	731, 136, 136, 136, 704, 558, 149, 308, 109, 715,
	4, 566, 631, 520, 184, 575, 510, 317, 569, 113,
	119, 363, 373, 312, 278, 130, 8, 311, 400, 145,
	7, 218, 81, 126, 225, 226, 227, 228, 229, 148,
	501, 230, 231, 232, 233, 234, 235, 236, 77, 239,
	280, 141, 247, 248, 249, 309, 310, 135, 5, 6,
	2, 187, 253, 123, 502, 418, 262, 263, 125, 265,
	266, 407, 764, 765, 775, 764, 765, 258, 694, 138,
	139, 683, 243, 79, 222, 222, 223, 401, 282, 102,
	690, 604, 587, 524, 102, 848, 115, 102, 102, 285,
	220, 220, 803, 289, 290, 601, 902, 903, 645, 800,
	314, 797, 757, 602, 319, 320, 302, 894, 855, 286,
	823, 288, 833, 821, 529, 529, 295, 810, 529, 301,
	763, 529, 332, 333, 334, 335, 336, 337, 338, 339,
	340, 341, 342, 343, 344, 345, 346, 347, 348, 349,
	350, 351, 352, 353, 354, 355, 356, 357, 43, 359,
	361, 215, 365, 402, 132, 367, 255, 110, 103, 274,
	276, 272, 258, 103, 244, 291, 103, 103, 787, 410,
	383, 385, 386, 387, 388, 389, 390, 391, 392, 393,
	394, 395, 396, 316, 115, 397, 136, 399, 504, 600,
	706, 635, 404, 379, 629, 808, 328, 540, 778, 752,
	219, 224, 223, 222, 736, 666, 570, 579, 298, 136,
	375, 183, 115, 331, 102, 217, 413, 327, 897, 220,
	325, 136, 304, 794, 795, 419, 499, 245, 246, 644,
	358, 511, 512, 880, 298, 513, 873, 869, 872, 864,
	854, 366, 516, 517, 216, 817, 521, 811, 282, 76,
	804, 255, 506, 761, 257, 112, 749, 720, 718, 895,
	114, 716, 115, 398, 832, 714, 711, 548, 115, 222,
	304, 533, 507, 142, 530, 381, 544, 369, 722, 323,
	132, 505, 302, 110, 322, 220, 406, 881, 508, 4,
	321, 292, 523, 103, 816, 536, 815, 539, 417, 805,
	554, 799, 149, 730, 719, 8, 222, 703, 498, 7,
	699, 572, 573, 697, 408, 409, 660, 572, 573, 782,
	786, 648, 220, 636, 370, 809, 622, 592, 543, 364,
	132, 557, 259, 110, 287, 735, 132, 5, 6, 110,
	408, 531, 409, 409, 408, 777, 724, 552, 702, 582,
	275, 583, 537, 273, 584, 585, 571, 115, 112, 577,
	534, 555, 581, 107, 563, 330, 553, 551, 371, 326,
	223, 547, 324, 590, 303, 545, 153, 155, 154, 528,
	115, 380, 102, 378, 285, 574, 297, 603, 108, 115,
	863, 277, 606, 264, 261, 415, 178, 371, 179, 151,
	152, 156, 158, 157, 170, 171, 168, 169, 172, 173,
	174, 175, 176, 166, 167, 160, 161, 159, 162, 164,
	165, 561, 177, 721, 260, 132, 238, 259, 110, 106,
	876, 214, 527, 182, 163, 679, 680, 681, 678, 677,
	676, 679, 680, 681, 678, 677, 676, 181, 132, 180,
	134, 110, 133, 221, 129, 589, 111, 300, 300, 300,
	538, 103, 115, 115, 503, 300, 252, 403, 251, 576,
	374, 377, 244, 605, 875, 136, 610, 410, 874, 672,
	300, 732, 674, 118, 144, 672, 411, 146, 674, 121,
	122, 728, 729, 621, 244, 315, 282, 624, 691, 282,
	244, 420, 500, 74, 75, 614, 742, 741, 242, 285,
	630, 542, 144, 865, 827, 619, 859, 535, 640, 319,
	642, 613, 847, 740, 302, 611, 633, 647, 829, 4,
	751, 646, 299, 120, 296, 245, 246, 539, 571, 539,
	783, 659, 244, 627, 638, 8, 146, 410, 571, 7,
	412, 667, 609, 607, 189, 571, 641, 245, 246, 656,
	115, 581, 514, 245, 246, 826, 623, 682, 244, 858,
	115, 649, 692, 267, 598, 142, 127, 5, 6, 664,
	665, 541, 222, 222, 687, 529, 511, 121, 122, 372,
	193, 521, 679, 680, 681, 678, 677, 676, 220, 220,
	250, 294, 244, 192, 515, 245, 246, 271, 244, 269,
	270, 712, 191, 241, 596, 705, 812, 764, 765, 696,
	709, 633, 698, 185, 700, 282, 163, 707, 539, 726,
	268, 245, 246, 539, 539, 188, 672, 663, 710, 674,
	767, 764, 765, 194, 195, 717, 571, 743, 222, 744,
	594, 45, 597, 595, 737, 177, 780, 581, 748, 382,
	750, 186, 834, 733, 220, 245, 246, 163, 746, 725,
	828, 245, 246, 282, 788, 222, 196, 198, 197, 785,
	329, 305, 747, 683, 634, 319, 162, 164, 165, 190,
	177, 220, 705, 755, 633, 282, 117, 708, 758, 661,
	754, 756, 163, 620, 781, 539, 759, 539, 364, 651,
	769, 773, 615, 559, 1, 549, 766, 753, 768, 771,
	796, 525, 762, 824, 784, 240, 237, 509, 679, 680,
	681, 678, 677, 676, 59, 806, 256, 58, 254, 774,
	798, 801, 813, 78, 814, 222, 105, 519, 376, 116,
	820, 293, 802, 608, 539, 48, 403, 612, 49, 831,
	80, 220, 819, 593, 69, 571, 835, 822, 901, 844,
	841, 830, 672, 842, 701, 674, 840, 839, 837, 853,
	843, 679, 680, 681, 678, 677, 676, 793, 671, 852,
	789, 738, 673, 861, 792, 862, 670, 857, 669, 866,
	727, 723, 818, 850, 658, 868, 655, 281, 279, 362,
	147, 844, 143, 771, 867, 745, 140, 871, 643, 849,
	318, 637, 843, 877, 878, 15, 42, 879, 85, 86,
	87, 88, 89, 14, 41, 47, 44, 71, 72, 565,
	73, 567, 37, 885, 882, 306, 3, 886, 423, 887,
	891, 890, 889, 734, 571, 662, 0, 0, 0, 581,
	0, 0, 0, 0, 896, 0, 898, 0, 899, 0,
	0, 651, 0, 53, 54, 904, 0, 0, 0, 55,
	0, 56, 51, 52, 60, 61, 62, 63, 64, 65,
	66, 68, 0, 107, 82, 50, 0, 0, 0, 0,
	24, 74, 75, 0, 0, 0, 67, 46, 90, 91,
	35, 0, 102, 0, 26, 0, 0, 0, 108, 25,
	17, 16, 0, 18, 0, 29, 0, 30, 0, 0,
	19, 0, 0, 0, 20, 21, 34, 36, 12, 22,
	32, 0, 0, 33, 11, 0, 23, 0, 28, 83,
	84, 9, 38, 39, 40, 0, 0, 0, 0, 106,
	0, 99, 95, 96, 97, 92, 93, 0, 0, 0,
	0, 0, 0, 100, 0, 0, 0, 0, 10, 98,
	94, 110, 0, 57, 0, 31, 13, 628, 154, 70,
	101, 103, 85, 86, 87, 88, 89, 0, 0, 0,
	0, 71, 72, 0, 73, 0, 178, 0, 179, 151,
	152, 156, 158, 157, 170, 171, 168, 169, 172, 173,
	174, 175, 176, 166, 167, 160, 161, 159, 162, 164,
	165, 0, 177, 0, 0, 0, 0, 53, 54, 0,
	0, 0, 0, 55, 163, 56, 51, 52, 60, 61,
	62, 63, 64, 65, 66, 68, 0, 107, 82, 50,
	0, 0, 0, 0, 24, 74, 75, 0, 0, 0,
	67, 46, 90, 91, 35, 0, 102, 0, 26, 0,
	0, 0, 108, 25, 17, 16, 0, 18, 0, 29,
	0, 30, 0, 0, 19, 0, 0, 0, 20, 21,
	34, 36, 12, 22, 32, 0, 0, 33, 11, 0,
	23, 0, 28, 83, 84, 9, 38, 39, 40, 0,
	0, 0, 0, 106, 0, 99, 95, 96, 97, 92,
	93, 0, 0, 0, 0, 0, 0, 100, 0, 0,
	0, 0, 10, 98, 94, 110, 0, 57, 0, 31,
	13, 532, 416, 70, 101, 103, 85, 86, 87, 88,
	89, 0, 0, 0, 0, 71, 72, 178, 73, 179,
	151, 152, 156, 158, 157, 170, 171, 168, 169, 172,
	173, 174, 175, 176, 166, 167, 160, 161, 159, 162,
	164, 165, 0, 177, 0, 0, 0, 0, 0, 0,
	0, 53, 54, 0, 0, 163, 0, 55, 0, 56,
	51, 52, 60, 61, 62, 63, 64, 65, 66, 68,
	0, 107, 82, 50, 0, 0, 0, 0, 24, 74,
	75, 0, 0, 0, 67, 46, 90, 91, 35, 0,
	102, 0, 26, 0, 0, 0, 108, 25, 17, 16,
	0, 18, 0, 29, 0, 30, 0, 0, 19, 0,
	0, 0, 20, 21, 34, 36, 12, 22, 32, 0,
	0, 33, 11, 0, 23, 0, 28, 83, 84, 9,
	38, 39, 40, 0, 0, 0, 0, 106, 0, 99,
	95, 96, 97, 92, 93, 0, 0, 0, 0, 0,
	0, 100, 0, 0, 0, 0, 10, 98, 94, 110,
	0, 57, 0, 31, 13, 155, 154, 70, 101, 103,
	85, 86, 87, 88, 89, 0, 0, 0, 0, 71,
	72, 0, 73, 0, 178, 0, 179, 151, 152, 156,
	158, 157, 170, 171, 168, 169, 172, 173, 174, 175,
	176, 166, 167, 160, 161, 159, 162, 164, 165, 0,
	177, 0, 0, 0, 0, 53, 54, 0, 0, 0,
	0, 55, 163, 56, 51, 52, 60, 61, 62, 63,
	64, 65, 66, 68, 0, 107, 82, 50, 0, 0,
	0, 0, 24, 74, 75, 0, 0, 0, 67, 46,
	90, 91, 35, 0, 102, 0, 26, 0, 0, 0,
	108, 25, 17, 16, 0, 18, 0, 29, 0, 30,
	0, 0, 19, 0, 0, 0, 20, 21, 34, 36,
	0, 22, 32, 0, 0, 33, 0, 0, 23, 0,
	28, 83, 84, 313, 38, 39, 40, 0, 0, 0,
	0, 106, 0, 99, 95, 96, 97, 92, 93, 0,
	0, 0, 0, 0, 0, 100, 0, 0, 0, 0,
	132, 98, 94, 110, 0, 57, 0, 31, 13, 905,
	0, 70, 101, 103, 85, 86, 87, 88, 89, 0,
	0, 0, 0, 71, 72, 178, 73, 179, 151, 152,
	156, 158, 157, 170, 171, 168, 169, 172, 173, 174,
	175, 176, 166, 167, 160, 161, 159, 162, 164, 165,
	0, 177, 0, 0, 0, 0, 0, 0, 0, 53,
	54, 0, 0, 163, 0, 55, 0, 56, 51, 52,
	60, 61, 62, 63, 64, 65, 66, 68, 0, 107,
	82, 50, 0, 0, 0, 0, 24, 74, 75, 0,
	0, 0, 67, 46, 90, 91, 35, 0, 102, 0,
	26, 0, 0, 0, 108, 25, 17, 16, 0, 18,
	0, 29, 0, 30, 0, 0, 19, 0, 0, 0,
	20, 21, 34, 36, 0, 22, 32, 0, 0, 33,
	0, 0, 23, 0, 28, 83, 84, 313, 38, 39,
	40, 0, 0, 0, 0, 106, 0, 99, 95, 96,
	97, 92, 93, 0, 0, 0, 0, 0, 0, 100,
	0, 0, 0, 0, 132, 98, 94, 110, 0, 57,
	0, 31, 13, 900, 0, 70, 101, 103, 85, 86,
	87, 88, 89, 0, 0, 0, 0, 71, 72, 0,
	73, 179, 151, 152, 156, 158, 157, 170, 171, 168,
	169, 172, 173, 174, 175, 176, 166, 167, 160, 161,
	159, 162, 164, 165, 0, 177, 0, 0, 0, 0,
	0, 0, 0, 53, 54, 0, 0, 163, 0, 55,
	0, 56, 51, 52, 60, 61, 62, 63, 64, 65,
	66, 68, 0, 107, 82, 50, 0, 0, 0, 0,
	24, 74, 75, 0, 0, 0, 67, 46, 90, 91,
	35, 0, 102, 0, 26, 0, 0, 0, 108, 25,
	17, 16, 0, 18, 0, 29, 0, 30, 0, 0,
	19, 0, 0, 0, 20, 21, 34, 36, 0, 22,
	32, 0, 0, 33, 0, 0, 23, 0, 28, 83,
	84, 313, 38, 39, 40, 0, 0, 0, 0, 106,
	0, 99, 95, 96, 97, 92, 93, 0, 0, 0,
	0, 0, 0, 100, 0, 0, 0, 0, 132, 98,
	94, 110, 0, 57, 0, 31, 13, 893, 0, 70,
	101, 103, 85, 86, 87, 88, 89, 0, 0, 0,
	0, 71, 72, 0, 73, 152, 156, 158, 157, 170,
	171, 168, 169, 172, 173, 174, 175, 176, 166, 167,
	160, 161, 159, 162, 164, 165, 0, 177, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 53, 54, 163,
	0, 0, 0, 55, 0, 56, 51, 52, 60, 61,
	62, 63, 64, 65, 66, 68, 0, 107, 82, 50,
	0, 0, 0, 0, 24, 74, 75, 0, 0, 0,
	67, 46, 90, 91, 35, 0, 102, 0, 26, 0,
	0, 0, 108, 25, 17, 16, 0, 18, 892, 29,
	0, 30, 0, 0, 19, 0, 0, 0, 20, 21,
	34, 36, 0, 22, 32, 0, 0, 33, 0, 0,
	23, 0, 28, 83, 84, 313, 38, 39, 40, 0,
	0, 0, 0, 106, 0, 99, 95, 96, 97, 92,
	93, 0, 0, 0, 0, 0, 0, 100, 0, 0,
	0, 0, 132, 98, 94, 110, 0, 57, 0, 31,
	13, 0, 0, 70, 101, 103, 85, 86, 87, 88,
	89, 0, 0, 0, 0, 71, 72, 0, 73, 0,
	156, 158, 157, 170, 171, 168, 169, 172, 173, 174,
	175, 176, 166, 167, 160, 161, 159, 162, 164, 165,
	0, 177, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 53, 54, 163, 0, 0, 0, 55, 0, 56,
	51, 52, 60, 61, 62, 63, 64, 65, 66, 68,
	0, 107, 82, 50, 0, 0, 0, 0, 24, 74,
	75, 0, 0, 0, 67, 46, 90, 91, 35, 0,
	102, 0, 26, 0, 0, 0, 108, 25, 17, 16,
	0, 18, 0, 29, 0, 30, 0, 0, 19, 0,
	0, 0, 20, 21, 34, 36, 0, 22, 32, 0,
	0, 33, 0, 0, 23, 0, 28, 83, 84, 313,
	38, 39, 40, 0, 0, 0, 0, 106, 0, 99,
	95, 96, 97, 92, 93, 0, 0, 0, 0, 0,
	0, 100, 0, 0, 0, 0, 132, 98, 94, 110,
	0, 57, 0, 31, 13, 884, 0, 70, 101, 103,
	85, 86, 87, 88, 89, 0, 0, 0, 0, 71,
	72, 0, 73, 0, 0, 158, 157, 170, 171, 168,
	169, 172, 173, 174, 175, 176, 166, 167, 160, 161,
	159, 162, 164, 165, 0, 177, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 53, 54, 163, 0, 0,
	0, 55, 0, 56, 51, 52, 60, 61, 62, 63,
	64, 65, 66, 68, 0, 107, 82, 50, 0, 0,
	0, 0, 24, 74, 75, 0, 0, 0, 67, 46,
	90, 91, 35, 0, 102, 0, 26, 0, 0, 0,
	108, 25, 17, 16, 0, 18, 0, 29, 0, 30,
	0, 0, 19, 0, 0, 0, 20, 21, 34, 36,
	0, 22, 32, 0, 0, 33, 0, 0, 23, 0,
	28, 83, 84, 313, 38, 39, 40, 0, 0, 0,
	0, 106, 0, 99, 95, 96, 97, 92, 93, 0,
	0, 0, 0, 0, 0, 100, 0, 0, 0, 0,
	132, 98, 94, 110, 0, 57, 0, 31, 13, 883,
	0, 70, 101, 103, 85, 86, 87, 88, 89, 0,
	0, 0, 0, 71, 72, 0, 73, 157, 170, 171,
	168, 169, 172, 173, 174, 175, 176, 166, 167, 160,
	161, 159, 162, 164, 165, 0, 177, 160, 161, 159,
	162, 164, 165, 0, 177, 0, 0, 0, 163, 53,
	54, 0, 0, 0, 0, 55, 163, 56, 51, 52,
	60, 61, 62, 63, 64, 65, 66, 68, 0, 107,
	82, 50, 0, 0, 0, 0, 24, 74, 75, 0,
	0, 0, 67, 46, 90, 91, 35, 0, 102, 0,
	26, 0, 0, 0, 108, 25, 17, 16, 0, 18,
	0, 29, 0, 30, 0, 0, 19, 0, 0, 0,
	20, 21, 34, 36, 0, 22, 32, 0, 0, 33,
	0, 0, 23, 0, 28, 83, 84, 313, 38, 39,
	40, 0, 0, 0, 0, 106, 0, 99, 95, 96,
	97, 92, 93, 0, 0, 0, 0, 0, 0, 100,
	0, 0, 0, 0, 132, 98, 94, 110, 0, 57,
	0, 31, 13, 860, 0, 70, 101, 103, 85, 86,
	87, 88, 89, 0, 0, 0, 0, 71, 72, 0,
	73, 170, 171, 168, 169, 172, 173, 174, 175, 176,
	166, 167, 160, 161, 159, 162, 164, 165, 0, 177,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 163, 0, 53, 54, 0, 0, 0, 0, 55,
	0, 56, 51, 52, 60, 61, 62, 63, 64, 65,
	66, 68, 0, 107, 82, 50, 0, 0, 0, 0,
	24, 74, 75, 0, 0, 0, 67, 46, 90, 91,
	35, 0, 102, 0, 26, 0, 0, 0, 108, 25,
	17, 16, 0, 18, 0, 29, 856, 30, 0, 0,
	19, 0, 0, 0, 20, 21, 34, 36, 0, 22,
	32, 0, 0, 33, 0, 0, 23, 0, 28, 83,
	84, 313, 38, 39, 40, 0, 0, 0, 0, 106,
	0, 99, 95, 96, 97, 92, 93, 0, 0, 0,
	0, 0, 0, 100, 0, 0, 0, 0, 132, 98,
	94, 110, 0, 57, 0, 31, 13, 0, 0, 70,
	101, 103, 85, 86, 87, 88, 89, 0, 0, 0,
	0, 71, 72, 0, 73, 173, 174, 175, 176, 166,
	167, 160, 161, 159, 162, 164, 165, 0, 177, 166,
	167, 160, 161, 159, 162, 164, 165, 0, 177, 0,
	163, 0, 0, 0, 0, 0, 0, 53, 54, 0,
	163, 0, 0, 55, 0, 56, 51, 52, 60, 61,
	62, 63, 64, 65, 66, 68, 0, 107, 82, 50,
	0, 0, 0, 0, 24, 74, 75, 0, 0, 0,
	67, 46, 90, 91, 35, 0, 102, 0, 26, 0,
	0, 0, 108, 25, 17, 16, 0, 18, 0, 29,
	0, 30, 776, 0, 19, 0, 0, 0, 20, 21,
	34, 36, 0, 22, 32, 0, 0, 33, 0, 0,
	23, 0, 28, 83, 84, 313, 38, 39, 40, 0,
	0, 0, 0, 106, 0, 99, 95, 96, 97, 92,
	93, 0, 0, 0, 0, 0, 0, 100, 0, 0,
	0, 0, 132, 98, 94, 110, 0, 57, 0, 31,
	13, 0, 0, 70, 101, 103, 85, 86, 87, 88,
	89, 0, 0, 0, 0, 71, 72, 0, 73, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 199, 200, 201, 202, 204, 205, 206,
	207, 208, 209, 210, 211, 203, 0, 0, 0, 0,
	0, 53, 54, 0, 0, 0, 0, 55, 0, 56,
	51, 52, 60, 61, 62, 63, 64, 65, 66, 68,
	0, 107, 82, 50, 212, 213, 0, 0, 24, 74,
	75, 0, 0, 0, 67, 46, 90, 91, 35, 0,
	102, 0, 26, 0, 0, 0, 108, 25, 17, 16,
	760, 18, 0, 29, 0, 30, 0, 0, 19, 0,
	0, 0, 20, 21, 34, 36, 0, 22, 32, 0,
	0, 33, 0, 0, 23, 0, 28, 83, 84, 313,
	38, 39, 40, 0, 0, 0, 0, 106, 0, 99,
	95, 96, 97, 92, 93, 0, 0, 0, 0, 0,
	0, 100, 0, 0, 0, 0, 132, 98, 94, 110,
	0, 57, 0, 31, 13, 0, 0, 70, 101, 103,
	85, 86, 87, 88, 89, 0, 0, 0, 0, 71,
	72, 0, 73, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 53, 54, 0, 0, 0,
	0, 55, 0, 56, 51, 52, 60, 61, 62, 63,
	64, 65, 66, 68, 0, 107, 82, 50, 0, 0,
	0, 686, 24, 74, 75, 0, 0, 0, 67, 46,
	90, 91, 35, 0, 102, 0, 26, 0, 0, 0,
	108, 25, 17, 16, 0, 18, 0, 29, 0, 30,
	0, 0, 19, 0, 0, 0, 20, 21, 34, 36,
	0, 22, 32, 0, 0, 33, 0, 0, 23, 0,
	28, 83, 84, 313, 38, 39, 40, 0, 0, 0,
	0, 106, 0, 99, 95, 96, 97, 92, 93, 0,
	0, 0, 0, 0, 0, 100, 0, 0, 0, 0,
	132, 98, 94, 110, 0, 57, 0, 31, 13, 0,
	0, 70, 101, 103, 85, 86, 87, 88, 89, 0,
	0, 0, 0, 71, 72, 0, 73, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 53,
	54, 0, 0, 0, 0, 55, 0, 56, 51, 52,
	60, 61, 62, 63, 64, 65, 66, 68, 0, 107,
	82, 50, 0, 0, 0, 0, 24, 74, 75, 0,
	0, 0, 67, 46, 90, 91, 35, 0, 102, 0,
	26, 0, 0, 0, 108, 25, 17, 16, 0, 18,
	0, 29, 0, 30, 0, 0, 19, 0, 0, 0,
	20, 21, 34, 36, 0, 22, 32, 0, 0, 33,
	0, 0, 23, 0, 28, 83, 84, 313, 38, 39,
	40, 0, 0, 0, 0, 106, 0, 99, 95, 96,
	97, 92, 93, 679, 680, 681, 678, 677, 676, 100,
	0, 0, 0, 0, 132, 98, 94, 110, 0, 57,
	0, 31, 13, 562, 0, 70, 101, 103, 431, 432,
	433, 434, 435, 0, 436, 437, 438, 474, 475, 0,
	0, 0, 0, 0, 0, 0, 0, 672, 0, 0,
	674, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	439, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	668, 0, 0, 0, 440, 441, 0, 444, 445, 446,
	425, 426, 427, 428, 429, 430, 442, 443, 0, 0,
	422, 0, 102, 0, 0, 0, 0, 0, 0, 447,
	448, 449, 450, 451, 452, 453, 454, 455, 456, 457,
	477, 478, 479, 480, 481, 469, 470, 471, 472, 473,
	458, 459, 460, 461, 462, 463, 464, 465, 466, 467,
	468, 0, 489, 487, 488, 484, 485, 0, 476, 482,
	483, 490, 491, 493, 492, 494, 495, 0, 0, 0,
	0, 0, 85, 86, 87, 88, 89, 0, 486, 497,
	496, 71, 72, 0, 73, 0, 421, 0, 0, 0,
	0, 103, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 53, 54, 0,
	0, 0, 0, 55, 0, 56, 51, 52, 60, 61,
	62, 63, 64, 65, 66, 68, 0, 107, 82, 50,
	0, 0, 0, 0, 24, 74, 75, 0, 0, 0,
	67, 46, 90, 91, 35, 0, 102, 0, 26, 0,
	0, 0, 108, 25, 17, 16, 0, 18, 0, 29,
	0, 30, 0, 0, 19, 0, 0, 0, 20, 21,
	34, 36, 0, 22, 32, 0, 0, 33, 0, 0,
	23, 0, 28, 83, 84, 313, 38, 39, 40, 0,
	0, 0, 0, 106, 0, 99, 95, 96, 97, 92,
	93, 0, 0, 0, 0, 0, 0, 100, 0, 0,
	0, 0, 132, 98, 94, 110, 0, 57, 0, 31,
	13, 307, 0, 70, 101, 103, 85, 86, 87, 88,
	89, 0, 0, 0, 0, 71, 72, 0, 73, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 53, 54, 0, 0, 0, 0, 55, 0, 56,
	51, 52, 60, 61, 62, 63, 64, 65, 66, 68,
	0, 107, 82, 50, 0, 0, 0, 0, 24, 74,
	75, 0, 0, 0, 67, 46, 90, 91, 35, 0,
	102, 0, 26, 0, 0, 0, 108, 25, 17, 16,
	0, 18, 0, 29, 0, 30, 0, 0, 19, 0,
	0, 0, 20, 21, 34, 36, 0, 22, 32, 0,
	0, 33, 0, 0, 23, 0, 28, 83, 84, 313,
	38, 39, 40, 0, 0, 0, 0, 106, 0, 99,
	95, 96, 97, 92, 93, 0, 0, 0, 0, 0,
	0, 100, 0, 0, 0, 0, 132, 98, 94, 110,
	0, 57, 0, 31, 13, 0, 0, 70, 101, 103,
	431, 432, 433, 434, 435, 0, 436, 437, 438, 474,
	475, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 439, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 440, 441, 0, 444,
	445, 446, 425, 426, 427, 428, 429, 430, 442, 443,
	0, 0, 846, 0, 0, 0, 0, 0, 0, 0,
	0, 447, 448, 449, 450, 451, 452, 453, 454, 455,
	456, 457, 477, 478, 479, 480, 481, 469, 470, 471,
	472, 473, 458, 459, 460, 461, 462, 463, 464, 465,
	466, 467, 468, 0, 489, 487, 488, 484, 485, 0,
	476, 482, 483, 490, 491, 493, 492, 494, 495, 431,
	432, 433, 434, 435, 0, 436, 437, 438, 474, 475,
	845, 497, 496, 110, 0, 0, 0, 0, 0, 870,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 439, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 440, 441, 0, 444, 445,
	446, 425, 426, 427, 428, 429, 430, 442, 443, 0,
	0, 846, 0, 0, 0, 0, 0, 0, 0, 0,
	447, 448, 449, 450, 451, 452, 453, 454, 455, 456,
	457, 477, 478, 479, 480, 481, 469, 470, 471, 472,
	473, 458, 459, 460, 461, 462, 463, 464, 465, 466,
	467, 468, 0, 489, 487, 488, 484, 485, 0, 476,
	482, 483, 490, 491, 493, 492, 494, 495, 0, 0,
	0, 0, 0, 0, 85, 86, 87, 88, 89, 845,
	497, 496, 110, 71, 72, 0, 73, 0, 836, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 772, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 53,
	54, 0, 0, 0, 0, 55, 0, 56, 51, 52,
	60, 61, 62, 63, 64, 65, 66, 68, 0, 107,
	82, 50, 0, 0, 0, 0, 24, 0, 0, 0,
	0, 0, 67, 46, 90, 91, 35, 0, 102, 0,
	26, 0, 0, 0, 108, 25, 17, 16, 0, 18,
	0, 29, 0, 30, 0, 0, 19, 0, 0, 0,
	20, 21, 34, 131, 0, 22, 32, 0, 0, 33,
	0, 0, 23, 0, 28, 83, 84, 0, 0, 0,
	0, 0, 0, 0, 0, 106, 0, 99, 95, 96,
	97, 92, 93, 0, 0, 0, 0, 0, 0, 100,
	0, 0, 0, 0, 132, 98, 94, 110, 0, 57,
	0, 31, 13, 0, 0, 70, 101, 103, 85, 86,
	87, 88, 89, 0, 0, 0, 0, 71, 72, 0,
	73, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 851, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 53, 54, 0, 0, 0, 0, 55,
	0, 56, 51, 52, 60, 61, 62, 63, 64, 65,
	66, 68, 0, 107, 82, 50, 0, 0, 0, 0,
	24, 0, 0, 0, 0, 0, 67, 46, 90, 91,
	35, 0, 102, 0, 26, 0, 0, 0, 108, 25,
	17, 16, 0, 18, 0, 29, 0, 30, 0, 0,
	19, 0, 0, 0, 20, 21, 34, 131, 0, 22,
	32, 0, 0, 33, 0, 0, 23, 0, 28, 83,
	84, 0, 0, 0, 0, 0, 0, 0, 0, 106,
	0, 99, 95, 96, 97, 92, 93, 0, 0, 0,
	0, 0, 0, 100, 0, 0, 0, 0, 132, 98,
	94, 110, 0, 57, 0, 31, 13, 0, 0, 70,
	101, 103, 85, 86, 87, 88, 89, 0, 0, 0,
	0, 71, 72, 0, 73, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 688,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 53, 54, 0,
	0, 0, 0, 55, 0, 56, 51, 52, 60, 61,
	62, 63, 64, 65, 66, 68, 0, 107, 82, 50,
	0, 0, 0, 0, 24, 0, 0, 0, 0, 0,
	67, 46, 90, 91, 35, 0, 102, 0, 26, 0,
	0, 0, 108, 25, 17, 16, 0, 18, 0, 29,
	0, 30, 0, 0, 19, 0, 0, 0, 20, 21,
	34, 131, 0, 22, 32, 0, 0, 33, 0, 0,
	23, 0, 28, 83, 84, 0, 0, 0, 0, 0,
	0, 0, 0, 106, 0, 99, 95, 96, 97, 92,
	93, 0, 0, 0, 0, 0, 0, 100, 0, 0,
	0, 0, 132, 98, 94, 110, 0, 57, 0, 31,
	13, 0, 0, 70, 101, 103, 85, 86, 87, 88,
	89, 0, 0, 0, 0, 71, 72, 0, 73, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 657, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 53, 54, 0, 0, 0, 0, 55, 0, 56,
	51, 52, 60, 61, 62, 63, 64, 65, 66, 68,
	0, 107, 82, 50, 0, 0, 0, 0, 24, 0,
	0, 0, 0, 0, 67, 46, 90, 91, 35, 0,
	102, 0, 26, 0, 0, 0, 108, 25, 17, 16,
	0, 18, 0, 29, 0, 30, 0, 0, 19, 0,
	0, 0, 20, 21, 34, 131, 0, 22, 32, 0,
	0, 33, 0, 0, 23, 0, 28, 83, 84, 0,
	0, 0, 0, 0, 0, 0, 0, 106, 0, 99,
	95, 96, 97, 92, 93, 0, 0, 0, 0, 0,
	0, 100, 0, 0, 0, 0, 132, 98, 94, 110,
	0, 57, 0, 31, 13, 0, 0, 70, 101, 103,
	85, 86, 87, 88, 89, 0, 0, 0, 0, 71,
	72, 0, 73, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 639, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 53, 54, 0, 0, 0,
	0, 55, 0, 56, 51, 52, 60, 61, 62, 63,
	64, 65, 66, 68, 0, 107, 82, 50, 0, 0,
	0, 0, 24, 0, 0, 0, 0, 0, 67, 46,
	90, 91, 35, 0, 102, 0, 26, 0, 0, 0,
	108, 25, 17, 16, 0, 18, 0, 29, 0, 30,
	0, 0, 19, 0, 0, 0, 20, 21, 34, 131,
	0, 22, 32, 0, 0, 33, 0, 0, 23, 0,
	28, 83, 84, 0, 0, 0, 0, 0, 0, 0,
	0, 106, 0, 99, 95, 96, 97, 92, 93, 0,
	0, 0, 0, 0, 0, 100, 0, 0, 0, 0,
	132, 98, 94, 110, 0, 57, 0, 31, 13, 0,
	0, 70, 101, 103, 85, 86, 87, 88, 89, 0,
	0, 0, 0, 71, 72, 0, 73, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 53,
	54, 0, 0, 0, 0, 55, 0, 56, 51, 52,
	60, 61, 62, 63, 64, 65, 66, 68, 0, 107,
	82, 50, 0, 0, 0, 0, 24, 0, 0, 0,
	0, 0, 67, 46, 90, 91, 35, 0, 102, 0,
	26, 0, 0, 0, 108, 25, 17, 16, 0, 18,
	0, 29, 0, 30, 0, 0, 19, 0, 0, 0,
	20, 21, 34, 131, 0, 22, 32, 0, 0, 33,
	0, 0, 23, 0, 28, 83, 84, 0, 0, 0,
	0, 0, 0, 0, 0, 106, 0, 99, 95, 96,
	97, 92, 93, 0, 0, 0, 0, 0, 0, 100,
	0, 0, 0, 0, 132, 98, 94, 110, 0, 57,
	0, 31, 13, 0, 0, 70, 101, 103, 431, 432,
	433, 434, 435, 0, 436, 437, 438, 474, 475, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	439, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 440, 441, 0, 444, 445, 446,
	425, 426, 427, 428, 429, 430, 442, 443, 0, 0,
	422, 0, 0, 0, 0, 0, 0, 0, 0, 447,
	448, 449, 450, 451, 452, 453, 454, 455, 456, 457,
	477, 478, 479, 480, 481, 469, 470, 471, 472, 473,
	458, 459, 460, 461, 462, 463, 464, 465, 466, 467,
	468, 0, 489, 487, 488, 484, 485, 0, 476, 482,
	483, 490, 491, 493, 492, 494, 495, 431, 432, 433,
	434, 435, 0, 436, 437, 438, 474, 475, 486, 497,
	496, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 439,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 440, 441, 0, 444, 445, 446, 679,
	680, 681, 678, 677, 676, 442, 443, 0, 0, 888,
	0, 0, 0, 0, 0, 0, 0, 0, 447, 448,
	449, 450, 451, 452, 453, 454, 455, 456, 457, 477,
	478, 479, 480, 481, 469, 470, 471, 472, 473, 458,
	459, 460, 461, 462, 463, 464, 465, 466, 467, 468,
	0, 489, 487, 488, 484, 485, 0, 476, 482, 483,
	490, 491, 493, 492, 494, 495, 0, 0, 0, 0,
	0, 85, 86, 87, 88, 89, 0, 486, 497, 496,
	71, 72, 0, 73, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 283, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 53, 54, 0, 0,
	0, 0, 55, 0, 56, 51, 52, 60, 61, 62,
	63, 64, 65, 66, 68, 0, 107, 82, 50, 0,
	0, 0, 0, 137, 0, 0, 0, 0, 0, 67,
	0, 90, 91, 115, 0, 102, 0, 0, 0, 0,
	0, 108, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	131, 0, 0, 0, 0, 85, 86, 87, 88, 89,
	0, 0, 83, 84, 71, 72, 0, 73, 0, 0,
	0, 284, 106, 0, 99, 95, 96, 97, 92, 93,
	0, 0, 0, 0, 0, 0, 100, 0, 625, 0,
	0, 132, 98, 94, 110, 0, 57, 0, 0, 0,
	53, 54, 70, 101, 103, 0, 55, 0, 56, 51,
	52, 60, 61, 62, 63, 64, 65, 66, 68, 0,
	107, 82, 50, 0, 0, 0, 0, 137, 0, 0,
	0, 0, 0, 67, 0, 90, 91, 115, 0, 102,
	0, 0, 0, 0, 0, 108, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 131, 0, 0, 0, 0, 85,
	86, 87, 88, 89, 0, 0, 83, 84, 71, 72,
	0, 73, 0, 0, 0, 626, 106, 0, 99, 95,
	96, 97, 92, 93, 0, 0, 0, 0, 0, 0,
	100, 0, 0, 0, 0, 132, 98, 94, 110, 0,
	57, 0, 0, 0, 53, 54, 70, 101, 103, 0,
	55, 0, 56, 51, 52, 60, 61, 62, 63, 64,
	65, 66, 68, 0, 107, 82, 50, 0, 0, 0,
	0, 137, 0, 0, 0, 0, 0, 67, 0, 90,
	91, 115, 0, 102, 0, 0, 0, 0, 0, 108,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 131, 0,
	0, 0, 0, 85, 86, 87, 88, 89, 0, 0,
	83, 84, 71, 72, 0, 73, 0, 0, 0, 0,
	106, 0, 99, 95, 96, 97, 92, 93, 0, 0,
	0, 0, 0, 0, 100, 0, 0, 0, 0, 132,
	98, 94, 110, 522, 57, 518, 0, 0, 53, 54,
	70, 101, 103, 0, 55, 0, 56, 51, 52, 60,
	61, 62, 63, 64, 65, 66, 68, 0, 107, 82,
	50, 0, 0, 0, 0, 137, 0, 0, 0, 0,
	0, 67, 0, 90, 91, 115, 0, 102, 0, 0,
	0, 0, 0, 108, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 131, 0, 0, 0, 0, 85, 86, 87,
	88, 89, 0, 0, 83, 84, 71, 72, 0, 73,
	0, 0, 0, 0, 106, 0, 99, 95, 96, 97,
	92, 93, 0, 0, 0, 0, 0, 0, 100, 0,
	0, 0, 0, 132, 98, 94, 110, 522, 57, 0,
	0, 0, 53, 54, 70, 101, 103, 0, 55, 0,
	56, 51, 52, 60, 61, 62, 63, 64, 65, 66,
	68, 0, 107, 82, 50, 0, 0, 0, 0, 137,
	0, 0, 0, 0, 0, 67, 0, 90, 91, 115,
	414, 102, 0, 0, 0, 0, 0, 108, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 131, 0, 0, 0,
	0, 85, 86, 87, 88, 89, 0, 0, 83, 84,
	71, 72, 0, 73, 0, 0, 0, 0, 106, 0,
	99, 95, 96, 97, 92, 93, 0, 0, 0, 0,
	0, 0, 100, 0, 384, 0, 0, 132, 98, 94,
	110, 0, 57, 0, 0, 0, 53, 54, 70, 101,
	103, 0, 55, 0, 56, 51, 52, 60, 61, 62,
	63, 64, 65, 66, 68, 0, 107, 82, 50, 0,
	0, 0, 0, 137, 0, 0, 0, 0, 0, 67,
	0, 90, 91, 115, 0, 102, 0, 0, 0, 0,
	0, 108, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	131, 0, 0, 0, 0, 85, 86, 87, 88, 89,
	0, 0, 83, 84, 71, 72, 0, 73, 0, 0,
	0, 0, 106, 0, 99, 95, 96, 97, 92, 93,
	0, 0, 360, 0, 0, 0, 100, 0, 0, 0,
	0, 132, 98, 94, 110, 0, 57, 0, 0, 0,
	53, 54, 70, 101, 103, 0, 55, 0, 56, 51,
	52, 60, 61, 62, 63, 64, 65, 66, 68, 0,
	107, 82, 50, 0, 0, 0, 0, 137, 0, 0,
	0, 0, 0, 67, 0, 90, 91, 115, 0, 102,
	0, 0, 0, 0, 0, 108, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 131, 0, 0, 0, 0, 85,
	86, 87, 88, 89, 0, 0, 83, 84, 71, 72,
	0, 73, 0, 0, 0, 0, 106, 0, 99, 95,
	96, 97, 92, 93, 0, 0, 0, 0, 0, 0,
	100, 0, 0, 0, 0, 132, 98, 94, 110, 0,
	57, 0, 0, 0, 53, 54, 70, 101, 103, 0,
	55, 0, 56, 51, 52, 60, 61, 62, 63, 64,
	65, 66, 68, 0, 107, 82, 50, 0, 0, 0,
	0, 137, 0, 0, 0, 0, 0, 67, 0, 90,
	91, 115, 0, 102, 0, 0, 0, 0, 0, 108,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 131, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	83, 84, 0, 0, 0, 0, 0, 0, 0, 0,
	106, 0, 99, 95, 96, 97, 92, 93, 0, 0,
	0, 0, 0, 0, 100, 153, 155, 154, 0, 132,
	98, 94, 110, 0, 57, 0, 0, 0, 0, 0,
	70, 101, 103, 0, 0, 178, 0, 179, 151, 152,
	156, 158, 157, 170, 171, 168, 169, 172, 173, 174,
	175, 176, 166, 167, 160, 161, 159, 162, 164, 165,
	0, 177, 153, 155, 154, 0, 0, 0, 0, 0,
	0, 0, 0, 163, 0, 0, 0, 0, 0, 0,
	0, 0, 178, 0, 179, 151, 152, 156, 158, 157,
	170, 171, 168, 169, 172, 173, 174, 175, 176, 166,
	167, 160, 161, 159, 162, 164, 165, 0, 177, 153,
	155, 154, 0, 0, 0, 0, 0, 0, 0, 0,
	163, 0, 0, 0, 0, 0, 0, 0, 0, 178,
	0, 179, 151, 152, 156, 158, 157, 170, 171, 168,
	169, 172, 173, 174, 175, 176, 166, 167, 160, 161,
	159, 162, 164, 165, 0, 177, 153, 155, 154, 0,
	0, 0, 0, 0, 0, 0, 0, 163, 695, 0,
	0, 0, 0, 0, 0, 0, 178, 0, 179, 151,
	152, 156, 158, 157, 170, 171, 168, 169, 172, 173,
	174, 175, 176, 166, 167, 160, 161, 159, 162, 164,
	165, 0, 177, 153, 155, 154, 0, 0, 0, 0,
	0, 0, 0, 0, 163, 693, 0, 0, 0, 0,
	0, 0, 0, 178, 0, 179, 151, 152, 156, 158,
	157, 170, 171, 168, 169, 172, 173, 174, 175, 176,
	166, 167, 160, 161, 159, 162, 164, 165, 0, 177,
	153, 155, 154, 0, 0, 0, 0, 0, 0, 0,
	0, 163, 689, 0, 0, 0, 0, 0, 0, 0,
	178, 0, 179, 151, 152, 156, 158, 157, 170, 171,
	168, 169, 172, 173, 174, 175, 176, 166, 167, 160,
	161, 159, 162, 164, 165, 0, 177, 153, 155, 154,
	0, 0, 0, 0, 0, 0, 0, 0, 163, 618,
	0, 0, 0, 0, 0, 0, 0, 178, 808, 179,
	151, 152, 156, 158, 157, 170, 171, 168, 169, 172,
	173, 174, 175, 176, 166, 167, 160, 161, 159, 162,
	164, 165, 0, 177, 153, 155, 154, 0, 0, 0,
	0, 0, 0, 0, 0, 163, 599, 0, 0, 0,
	0, 0, 0, 0, 178, 0, 179, 151, 152, 156,
	158, 157, 170, 171, 168, 169, 172, 173, 174, 175,
	176, 166, 167, 160, 161, 159, 162, 164, 165, 0,
	177, 153, 155, 154, 0, 0, 0, 0, 0, 0,
	0, 0, 163, 588, 0, 0, 0, 0, 0, 0,
	0, 178, 0, 179, 151, 152, 156, 158, 157, 170,
	171, 168, 169, 172, 173, 174, 175, 176, 166, 167,
	160, 161, 159, 162, 164, 165, 0, 177, 153, 155,
	154, 0, 0, 0, 0, 0, 0, 0, 809, 163,
	0, 0, 0, 0, 0, 0, 0, 0, 178, 0,
	179, 151, 152, 156, 158, 157, 170, 171, 168, 169,
	172, 173, 174, 175, 176, 166, 167, 160, 161, 159,
	162, 164, 165, 0, 177, 153, 155, 154, 0, 0,
	0, 0, 0, 0, 0, 368, 163, 0, 0, 0,
	0, 0, 0, 0, 0, 178, 0, 179, 151, 152,
	156, 158, 157, 170, 171, 168, 169, 172, 173, 174,
	175, 176, 166, 167, 160, 161, 159, 162, 164, 165,
	0, 177, 153, 155, 154, 0, 0, 0, 0, 0,
	0, 0, 150, 163, 0, 0, 0, 0, 0, 0,
	0, 0, 178, 0, 179, 151, 152, 156, 158, 157,
	170, 171, 168, 169, 172, 173, 174, 175, 176, 166,
	167, 160, 161, 159, 162, 164, 165, 0, 177, 153,
	155, 154, 0, 0, 0, 0, 0, 0, 713, 0,
	163, 0, 0, 0, 0, 0, 0, 0, 0, 178,
	0, 179, 151, 152, 156, 158, 157, 170, 171, 168,
	169, 172, 173, 174, 175, 176, 166, 167, 160, 161,
	159, 162, 164, 165, 0, 177, 153, 155, 154, 0,
	0, 0, 0, 0, 0, 685, 0, 163, 0, 0,
	0, 0, 0, 0, 0, 0, 178, 0, 179, 151,
	152, 156, 158, 157, 170, 171, 168, 169, 172, 173,
	174, 175, 176, 166, 167, 160, 161, 159, 162, 164,
	165, 0, 177, 153, 155, 154, 0, 0, 0, 0,
	0, 0, 684, 0, 163, 0, 0, 0, 0, 0,
	0, 0, 0, 178, 0, 179, 151, 152, 156, 158,
	157, 170, 171, 168, 169, 172, 173, 174, 175, 176,
	166, 167, 160, 161, 159, 162, 164, 165, 0, 177,
	153, 155, 154, 0, 0, 0, 0, 0, 0, 617,
	0, 163, 0, 0, 0, 0, 0, 0, 0, 0,
	178, 0, 179, 151, 152, 156, 158, 157, 170, 171,
	168, 169, 172, 173, 174, 175, 176, 166, 167, 160,
	161, 159, 162, 164, 165, 0, 177, 153, 155, 154,
	0, 0, 0, 0, 0, 0, 616, 0, 163, 0,
	0, 0, 0, 0, 0, 0, 0, 178, 0, 179,
	151, 152, 156, 158, 157, 170, 171, 168, 169, 172,
	173, 174, 175, 176, 166, 167, 160, 161, 159, 162,
	164, 165, 0, 177, 153, 155, 154, 0, 0, 0,
	0, 0, 0, 591, 0, 163, 0, 0, 0, 0,
	0, 0, 0, 0, 178, 0, 179, 151, 152, 156,
	158, 157, 170, 171, 168, 169, 172, 173, 174, 175,
	176, 166, 167, 160, 161, 159, 162, 164, 165, 0,
	177, 153, 155, 154, 0, 0, 0, 0, 0, 0,
	586, 0, 163, 0, 652, 0, 0, 0, 0, 0,
	0, 178, 0, 179, 151, 152, 156, 158, 157, 170,
	171, 168, 169, 172, 173, 174, 175, 176, 166, 167,
	160, 161, 159, 162, 164, 165, 654, 177, 0, 0,
	153, 155, 154, 223, 0, 0, 0, 550, 0, 163,
	0, 0, 0, 115, 0, 102, 0, 0, 0, 0,
	178, 108, 179, 151, 152, 156, 158, 157, 170, 171,
	168, 169, 172, 173, 174, 175, 176, 166, 167, 160,
	161, 159, 162, 164, 165, 0, 177, 0, 0, 0,
	0, 0, 0, 0, 546, 0, 0, 0, 163, 0,
	0, 653, 106, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 132, 0, 0, 110, 0, 221, 153, 155, 154,
	0, 0, 0, 0, 103, 560, 0, 0, 0, 0,
	0, 405, 0, 0, 0, 0, 0, 178, 556, 179,
	151, 152, 156, 158, 157, 170, 171, 168, 169, 172,
	173, 174, 175, 176, 166, 167, 160, 161, 159, 162,
	164, 165, 0, 177, 153, 155, 154, 0, 0, 526,
	0, 0, 0, 0, 0, 163, 0, 0, 0, 0,
	0, 0, 0, 0, 178, 0, 179, 151, 152, 156,
	158, 157, 170, 171, 168, 169, 172, 173, 174, 175,
	176, 166, 167, 160, 161, 159, 162, 164, 165, 0,
	177, 153, 155, 154, 0, 0, 0, 0, 0, 0,
	0, 0, 163, 0, 0, 0, 0, 0, 0, 0,
	0, 178, 0, 179, 151, 152, 156, 158, 157, 170,
	171, 168, 169, 172, 173, 174, 175, 176, 166, 167,
	160, 161, 159, 162, 164, 165, 0, 177, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 163,
}
var yyPact = [...]int{

	-1000, -1000, 1182, -1000, -1000, -1000, -1000, -1000, -1000, 327,
	128, 406, 520, -1000, -1000, -1000, 325, 4890, 323, 321,
	6135, 6135, 6135, 26, 429, 6135, -1000, 6651, 320, 318,
	304, -1000, 79, 6135, 567, 660, 628, 456, 556, 547,
	534, 600, 633, 2836, -1000, -1000, 302, -1000, -1000, 112,
	6135, 324, 324, 6135, 6135, 6135, 6135, 6135, -1000, -1000,
	6135, 6135, 6135, 6135, 6135, 6135, 6135, 297, 6135, -1000,
	550, 6135, 6135, 6135, -1000, -1000, -1000, 561, -1000, 345,
	343, -1000, 156, 295, 265, 6135, 6135, 264, 6135, 6135,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	510, 544, -1000, 29, 221, 221, 262, 5337, -1000, 257,
	514, 204, 514, -38, -1000, -1000, 160, 407, 255, 405,
	514, -1000, -1000, -1000, -1000, 243, -1000, 694, 3458, 6135,
	428, 628, 231, 6135, 6135, 159, 7351, 401, 153, 148,
	241, -1000, -1000, 238, 628, -1000, 693, 234, -1000, 7351,
	-1000, 6135, 6135, 6135, 6135, 6135, 6135, 6135, 6135, 6135,
	6135, 6135, 6135, 6135, 6135, 6135, 6135, 6135, 6135, 6135,
	6135, 6135, 6135, 6135, 6135, 6135, 6135, 30, 6021, 6135,
	324, 6135, 520, -1000, 6604, 146, -1000, 268, -1000, 533,
	-1000, 369, 78, 370, 254, 4890, 252, 144, 658, 5907,
	6135, 6135, 6135, 6135, 6135, 6135, 6135, 6135, 6135, 6135,
	6135, 6135, -1000, -1000, 6135, 6135, 6135, 21, -1000, -1000,
	561, 6135, -1000, -1000, -1000, 588, 588, 629, 588, 7121,
	588, 588, 588, 588, 588, 588, 588, -1000, 6135, 588,
	-74, 436, 414, -1000, 447, 5793, 324, 1495, 1167, 1495,
	6135, 3314, 3314, 221, -1000, 341, 149, 221, -1000, -1000,
	6135, 6135, 7351, 7351, 6135, 7351, 7351, 442, -1000, 484,
	106, 436, 6135, -1000, -1000, 5565, -1000, 5337, -51, 742,
	-1000, -1000, 7304, 324, 250, 529, 257, 143, 257, -1000,
	-1000, 1018, -1000, 140, 229, 390, 514, -1000, 333, 65,
	525, 384, -1000, -1000, 520, 6135, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, 246, 7074, 242, 239, 136, 736, 7351,
	7027, -1000, -1000, -1000, -1000, 26, -1000, 488, 237, 6135,
	-1000, 6135, 1821, 1985, 1334, 1495, 1006, 2149, 2473, 2310,
	664, 664, 664, 629, 588, 629, 629, 2318, 2318, 2632,
	2632, 2632, 2632, 2632, 2642, 2642, 2642, 2642, -1000, 7257,
	6135, 1659, 734, -1000, -1000, 7170, 291, 3150, -1000, -1000,
	235, 206, 369, 367, 301, -1000, 75, 301, 6135, -1000,
	6135, -1000, -1000, 1495, 6135, 1495, 1495, 1495, 1495, 1495,
	1495, 1495, 1495, 1495, 1495, 1495, 1495, 6980, -52, 6510,
	221, -1000, 6135, -1000, 6933, -1000, 197, -1000, -1000, -1000,
	-1000, 594, 518, 6463, 56, -30, 6135, -53, 221, -1000,
	-1000, 6135, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, 221, -1000,
	-1000, -1000, -1000, 26, 6135, 6135, 21, 26, 369, 733,
	-1000, 7351, 6886, 6839, -1000, -1000, -1000, 6416, -1000, 724,
	-1000, 7351, 6135, 196, -1000, 5337, 5451, -1000, 5337, -1000,
	-1000, 854, -1000, -1000, -1000, 62, 383, -1000, 514, 382,
	504, -1000, 59, -1000, 7351, 193, 4726, 6135, 6135, 6135,
	97, -1000, -1000, 206, 7351, -1000, 6135, 1659, 191, 324,
	7107, 4562, -1000, 206, 186, 720, -1000, 630, -1000, -1000,
	212, -1000, -1000, -1000, 367, 73, 301, -1000, 3217, -1000,
	704, -1000, 6792, 6745, 2986, 2473, 4398, -1000, -1000, -1000,
	6369, -1000, -1000, -54, -1000, -1000, 439, -1000, -1000, -1000,
	-1000, 6135, -1000, 1495, -1000, -1000, 6322, -1000, -1000, -66,
	6275, -1000, -1000, 367, 183, 6135, -1000, -1000, -1000, 180,
	5679, 7351, -1000, -1000, 7351, 324, 219, 177, -1000, 514,
	58, 718, -1000, -1000, 514, 504, 135, -1000, -1000, -1000,
	6698, 134, 7351, -1000, 130, 127, 174, 1659, 126, -1000,
	293, -1000, 324, 217, 5337, -1000, -1000, -1000, 404, 173,
	391, 206, 207, -1000, -1000, 72, -1000, 704, -1000, -1000,
	465, 423, 301, 735, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, 682, 301, 4890, 657, 125, -1000, -1000, -1000,
	-1000, -1000, 396, -1000, -1000, -1000, 67, -1000, -1000, -1000,
	-1000, -1000, 5337, -1000, 714, -1000, 514, -31, 504, -1000,
	718, -1000, 2822, 122, 6135, -13, -1000, 563, -1000, 391,
	-1000, 4070, 7107, -1000, 5337, -70, 2658, -1000, 216, 66,
	655, 655, 190, -1000, 482, -1000, -1000, 546, 189, -1000,
	687, 5054, 628, 92, -1000, -1000, -1000, -1000, -1000, -1000,
	3622, -32, -1000, 171, -34, 514, 714, -1000, -1000, -41,
	119, -1000, 169, -1000, 6135, 194, -16, 116, 539, 655,
	-1000, -1000, -1000, 166, 164, -1000, 114, 301, -1000, -19,
	206, -22, 507, 683, 395, -1000, -1000, 465, 6135, 133,
	-1000, 675, 5054, -1000, -1000, 3925, 3622, -1000, 389, -1000,
	-1000, -1000, -48, -1000, -1000, 4234, 6557, -1000, -1000, -1000,
	-1000, -1000, 109, -24, 2494, 4070, -1000, -1000, 511, -1000,
	2330, -1000, -1000, -1000, 260, -1000, -1000, 455, 6135, -1000,
	-1000, 7351, -1000, 5054, 6135, 108, -1000, 3786, -1000, 107,
	105, 387, 399, 307, -1000, 231, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, 3622, -1000, -1000, 102, -1000, 157, 301,
	-1000, 2166, 2002, -1000, 507, -1000, 7351, -1000, 7351, 206,
	-1000, -1000, -1000, -1000, 301, 5193, 5054, 1838, 3622, 1674,
	-1000, -25, -1000, -1000, -1000, -1000, 129, 704, -1000, -1000,
	5054, -1000, 87, -1000, -1000, 655, -1000, -1000, 1510, -35,
	-1000, -1000, -1000, -1000, 1346, -1000,
}
var yyPgo = [...]int{

	0, 681, 885, 883, 81, 6, 878, 3, 876, 28,
	14, 80, 27, 875, 1, 872, 76, 75, 871, 2,
	16, 38, 7, 869, 31, 0, 866, 865, 178, 279,
	864, 863, 856, 855, 851, 37, 850, 849, 848, 29,
	77, 846, 71, 842, 49, 840, 59, 839, 41, 18,
	44, 70, 838, 837, 11, 88, 53, 836, 834, 832,
	830, 17, 828, 826, 822, 5, 821, 13, 820, 10,
	818, 4, 817, 808, 9, 807, 806, 803, 800, 798,
	794, 538, 102, 793, 68, 103, 790, 788, 52, 785,
	48, 714, 781, 779, 32, 24, 513, 19, 15, 83,
	47, 43, 778, 42, 35, 84, 777, 33, 776, 773,
	85, 768, 767, 60, 82, 766, 764, 757, 36, 756,
	755, 20, 753, 8, 744, 25, 12,
}
var yyR1 = [...]int{

	0, 124, 5, 5, 5, 5, 5, 5, 5, 5,
	5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
	5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
	5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
	5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
	5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
	5, 5, 5, 5, 5, 5, 5, 5, 5, 6,
	6, 6, 6, 6, 6, 6, 7, 7, 11, 11,
	9, 9, 10, 10, 10, 8, 8, 8, 8, 8,
	8, 8, 8, 8, 8, 8, 8, 8, 8, 91,
	91, 92, 92, 93, 93, 125, 125, 94, 94, 95,
	95, 96, 96, 97, 97, 98, 98, 99, 99, 55,
	55, 14, 14, 13, 13, 13, 13, 13, 13, 12,
	12, 12, 12, 12, 12, 12, 12, 12, 12, 12,
	12, 12, 12, 12, 12, 12, 12, 12, 12, 12,
	12, 12, 12, 58, 58, 59, 59, 60, 60, 47,
	47, 48, 17, 2, 2, 3, 3, 16, 16, 15,
	15, 1, 1, 100, 101, 103, 103, 102, 102, 104,
	104, 49, 49, 49, 49, 37, 37, 54, 54, 57,
	57, 38, 38, 38, 38, 39, 39, 39, 126, 126,
	34, 34, 30, 30, 31, 31, 32, 32, 33, 33,
	22, 22, 23, 23, 24, 24, 18, 18, 20, 20,
	21, 21, 21, 19, 19, 105, 105, 106, 106, 107,
	107, 41, 41, 42, 43, 43, 44, 44, 61, 61,
	62, 62, 62, 62, 71, 71, 72, 72, 72, 73,
	73, 74, 74, 75, 76, 76, 76, 76, 77, 77,
	78, 79, 79, 63, 63, 70, 70, 64, 64, 65,
	65, 65, 65, 65, 65, 66, 66, 67, 67, 68,
	68, 69, 56, 45, 45, 46, 35, 35, 36, 36,
	111, 112, 112, 26, 26, 26, 26, 26, 26, 26,
	26, 26, 26, 26, 26, 26, 26, 26, 26, 26,
	26, 26, 26, 26, 26, 26, 26, 26, 26, 26,
	26, 26, 26, 26, 26, 26, 26, 26, 26, 26,
	26, 26, 26, 26, 26, 26, 26, 26, 26, 26,
	26, 26, 26, 26, 26, 26, 26, 26, 26, 26,
	26, 26, 26, 26, 26, 26, 26, 26, 26, 26,
	26, 26, 26, 26, 26, 26, 26, 4, 4, 121,
	121, 122, 122, 123, 123, 109, 109, 109, 109, 85,
	85, 114, 114, 119, 119, 120, 120, 120, 113, 113,
	88, 88, 88, 80, 80, 80, 80, 80, 80, 80,
	80, 80, 80, 80, 80, 80, 80, 80, 80, 84,
	84, 84, 25, 25, 40, 40, 86, 87, 87, 87,
	108, 108, 108, 27, 27, 27, 27, 27, 27, 28,
	28, 28, 29, 29, 29, 89, 89, 115, 115, 115,
	115, 115, 115, 110, 110, 110, 90, 90, 90, 50,
	51, 51, 52, 52, 53, 53, 53, 53, 53, 53,
	81, 81, 81, 81, 82, 82, 82, 82, 82, 82,
	82, 83, 83, 83, 83, 116, 116, 116, 116, 116,
	116, 116, 117, 117, 118,
}
var yyR2 = [...]int{

	0, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 2, 0,
	1, 3, 1, 2, 3, 1, 1, 1, 1, 1,
	4, 3, 5, 4, 3, 4, 3, 4, 3, 1,
	1, 6, 7, 6, 7, 0, 1, 3, 1, 3,
	1, 3, 1, 1, 2, 1, 3, 1, 2, 3,
	1, 2, 0, 1, 1, 1, 1, 1, 4, 3,
	1, 1, 5, 7, 9, 5, 3, 3, 3, 3,
	3, 3, 1, 2, 6, 7, 9, 5, 1, 6,
	3, 3, 2, 0, 9, 1, 3, 0, 4, 1,
	3, 1, 10, 0, 1, 0, 1, 8, 7, 1,
	2, 1, 1, 5, 6, 0, 2, 0, 2, 0,
	2, 1, 2, 4, 3, 1, 4, 1, 4, 1,
	4, 3, 4, 4, 5, 0, 5, 4, 1, 1,
	1, 4, 5, 6, 1, 3, 6, 7, 3, 6,
	1, 0, 1, 3, 4, 6, 0, 1, 1, 2,
	1, 1, 1, 0, 2, 2, 4, 1, 3, 1,
	2, 3, 1, 1, 3, 1, 1, 3, 2, 0,
	3, 4, 3, 9, 1, 3, 1, 2, 3, 1,
	2, 2, 2, 3, 3, 3, 4, 3, 1, 1,
	3, 1, 3, 1, 1, 0, 1, 1, 2, 1,
	1, 1, 1, 1, 1, 3, 1, 1, 3, 3,
	1, 3, 3, 3, 1, 1, 0, 1, 3, 1,
	7, 3, 2, 3, 4, 2, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 2, 2,
	2, 2, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 2,
	2, 2, 2, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 1, 5, 4, 3, 1, 2,
	2, 2, 2, 2, 2, 2, 2, 2, 1, 3,
	2, 1, 2, 4, 2, 10, 11, 0, 1, 0,
	4, 3, 1, 1, 2, 2, 4, 4, 2, 1,
	1, 1, 1, 0, 3, 0, 1, 1, 0, 1,
	4, 3, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 3, 2, 3, 3, 1, 1, 1,
	3, 3, 1, 1, 0, 1, 1, 1, 3, 1,
	1, 3, 1, 1, 4, 4, 4, 4, 1, 1,
	1, 3, 1, 4, 2, 3, 3, 1, 4, 4,
	3, 3, 3, 1, 3, 1, 1, 3, 1, 1,
	0, 1, 3, 1, 3, 1, 4, 2, 6, 4,
	2, 2, 1, 2, 1, 4, 3, 3, 3, 6,
	3, 1, 1, 2, 1, 5, 4, 2, 2, 4,
	2, 2, 1, 3, 1,
}
var yyChk = [...]int{

	-1000, -124, -11, -8, -12, -17, -16, -100, -101, 127,
	154, 120, 114, 162, -31, -33, 97, 96, 99, 106,
	110, 111, 115, 122, 76, 95, 90, -25, 124, 101,
	103, 161, 116, 119, 112, 86, 113, -15, 128, 129,
	130, -30, -32, -28, -26, -1, 83, -27, -89, -87,
	71, 58, 59, 49, 50, 55, 57, 159, -112, -116,
	60, 61, 62, 63, 64, 65, 66, 82, 67, -80,
	165, 13, 14, 16, 77, 78, -29, -84, -109, -85,
	-86, -88, 70, 125, 126, 4, 5, 6, 7, 8,
	84, 85, 141, 142, 156, 138, 139, 140, 155, 137,
	149, 166, 88, 167, -10, -108, 135, 69, 94, -9,
	157, 159, 157, -9, 162, 86, -93, -91, -96, -9,
	157, 113, 114, -99, -98, -55, -56, 86, -14, 159,
	-12, 113, 154, 159, 159, -40, -25, 76, -40, -40,
	-41, -42, -29, -43, 113, -44, 88, -45, -46, -25,
	161, 33, 34, 10, 12, 11, 35, 37, 36, 51,
	49, 50, 52, 68, 53, 54, 47, 48, 40, 41,
	38, 39, 42, 43, 44, 45, 46, 56, 30, 32,
	159, 159, 159, 162, -25, 86, 31, -4, 37, 128,
	-1, 86, 86, 86, 73, 74, 73, 75, 74, 17,
	18, 19, 20, 29, 21, 22, 23, 24, 25, 26,
	27, 28, 58, 59, 159, 69, 162, 133, -25, -28,
	-84, 159, -88, 76, -28, -25, -25, -25, -25, -25,
	-25, -25, -25, -25, -25, -25, -25, -119, 159, -25,
	-120, 93, -81, -82, 88, 151, 152, -25, -25, -25,
	69, 153, 153, -114, -111, -85, -115, 128, -10, -29,
	159, 159, -25, -25, 159, -25, -25, 93, 150, -81,
	-81, 93, 162, -29, -105, 159, -105, 159, -50, -52,
	-51, -53, -25, 37, 134, 157, -9, 160, -9, 161,
	162, -11, 161, -92, -96, -9, 157, 161, 9, 157,
	105, -9, -98, 161, 9, 17, -13, 163, -12, -17,
	-16, -100, -101, 127, -25, 97, -4, -35, -36, -25,
	-25, 161, 161, 161, 161, 9, 161, 9, -4, 17,
	161, 9, -25, -25, -25, -25, -25, -25, -25, -25,
	-25, -25, -25, -25, -25, -25, -25, -25, -25, -25,
	-25, -25, -25, -25, -25, -25, -25, -25, -114, -25,
	31, -25, -47, -48, -28, -25, -55, -14, 161, 161,
	86, 159, 86, -103, 131, 162, -102, 131, 159, -12,
	159, 161, 31, -25, 37, -25, -25, -25, -25, -25,
	-25, -25, -25, -25, -25, -25, -25, -25, -40, -25,
	-90, 86, 162, -29, -25, 160, -40, 165, -82, -82,
	93, 69, 133, -25, 87, -28, 15, -40, -110, -7,
	-29, 162, 86, -6, -5, 76, 77, 78, 79, 80,
	81, 4, 5, 6, 7, 8, 10, 11, 12, 56,
	70, 71, 82, 83, 73, 74, 75, 95, 96, 97,
	98, 99, 100, 101, 102, 103, 104, 105, 116, 117,
	118, 119, 120, 121, 122, 123, 124, 125, 126, 111,
	112, 113, 114, 115, 13, 14, 134, 106, 107, 108,
	109, 110, 135, 136, 131, 132, 154, 129, 130, 128,
	137, 138, 140, 139, 141, 142, 156, 155, -110, -7,
	-29, -113, -105, 153, 69, 162, 133, 153, -113, -117,
	-118, -25, -25, -25, 150, 150, 166, -25, 160, -106,
	-107, -25, 158, -50, 164, 9, 15, -28, 159, 86,
	161, -11, 163, 161, 161, 157, -9, -99, 157, -9,
	162, 86, 157, -56, -25, 159, 160, 159, 161, 9,
	160, -42, -44, 159, -25, -46, 31, -25, -125, 9,
	105, 160, 163, 159, -22, -23, -24, -18, -20, -21,
	30, -10, 135, 136, -103, -104, 132, -10, -61, 162,
	-71, -10, -25, -25, -14, -25, 160, 164, 163, -105,
	-25, 160, 160, -83, 86, 89, 50, 88, 86, 163,
	163, 69, 163, -25, 164, -105, -25, -105, -29, -40,
	-25, -90, -29, -103, -125, 9, 160, 160, 163, -125,
	9, -25, 160, -51, -25, 37, 134, -50, 163, 162,
	157, -94, -97, -98, -91, 162, 160, -34, -12, 31,
	-25, -35, -25, -38, 162, 31, -22, -25, 160, -48,
	-49, -28, 37, 134, 69, -57, -12, 31, -58, -22,
	160, 9, -2, 37, -21, -104, 162, -71, 163, -62,
	-63, -70, 120, -64, 123, -65, 81, 80, 79, 76,
	77, 78, -61, 9, 160, 160, 75, -12, 31, 163,
	164, 89, -25, 163, 164, 163, -104, 160, -118, 160,
	-107, -28, 159, 160, -95, -98, 162, -125, 9, -98,
	-94, 161, -14, 160, 161, -39, 161, -39, 161, 160,
	161, 160, 15, -28, 159, -50, -14, -60, 117, 118,
	160, -121, 120, -24, -3, 158, 162, -61, -66, -67,
	88, 114, 113, -71, -65, 163, -10, -12, 31, 161,
	-14, 164, 162, -50, -125, 9, -95, 163, -97, -125,
	98, 161, -35, 163, 108, 109, -39, 107, -39, -121,
	-54, -12, 31, -49, -50, 164, 104, 159, 162, -19,
	31, -19, 159, 88, -61, 163, 161, 9, 17, -68,
	-69, -7, -4, -72, 161, 162, -14, 163, -61, 160,
	163, -98, -125, 163, 161, 160, -25, -126, 31, 161,
	163, 161, 107, -19, -14, 160, 160, 161, -59, -10,
	-14, 162, -20, 162, -122, -123, 88, 37, 17, 163,
	-67, -25, 161, 9, 17, -7, 163, -73, -74, -75,
	-76, -78, -77, -10, -7, 154, 86, 163, 163, -37,
	-12, 31, -126, -14, 161, 162, 102, -54, 88, 35,
	163, -14, -14, 160, 9, 88, -25, -69, -25, 159,
	163, -74, 161, 161, 121, 105, 153, -14, -14, -14,
	161, 160, -10, 163, 163, -123, -22, -71, 86, -5,
	-65, -7, 100, 163, 162, 160, -7, 161, -14, -19,
	163, -79, 161, 162, -14, 163,
}
var yyDef = [...]int{

	79, -2, 1, 78, 85, 86, 87, 88, 89, 0,
	0, 0, 0, 122, 130, 131, 0, 0, 0, 0,
	414, 414, 414, 0, 379, 0, 142, 0, 0, 0,
	0, 148, 0, 0, 0, 80, 367, 0, 0, 0,
	0, 204, 0, -2, 413, 169, 0, -2, 430, 416,
	0, 0, 0, 0, 0, 0, 0, 0, 344, 348,
	0, 0, 0, 0, 0, 0, 0, 383, 0, 358,
	385, 0, 361, 0, 171, 172, 423, 408, 428, 0,
	0, -2, 0, 0, 0, 0, 0, 0, 0, 0,
	393, 394, 395, 396, 397, 398, 399, 400, 401, 402,
	0, 0, 432, 0, -2, 0, 0, 450, 392, 82,
	0, 0, 0, 0, 79, 80, 0, 0, 0, 115,
	0, 99, 100, 112, 117, 0, 120, 0, 0, 0,
	0, 367, 0, 286, 0, 0, 415, 379, 0, 0,
	0, 232, 233, 0, 367, 235, 236, 0, 284, 285,
	143, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 122, 0, 0, 152, 0, 368, 0,
	170, 175, 0, 177, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 308, 310, 0, 414, 0, 0, 295, -2,
	0, 0, -2, 379, -2, 329, 330, 331, 332, 0,
	349, 350, 351, 352, 353, 354, 355, 356, 414, 357,
	0, 386, 387, 462, 464, 0, 0, 360, 362, 364,
	414, 0, 0, 388, 292, 381, 382, 388, 380, 437,
	0, 0, 477, 478, 0, 480, 481, 0, 404, 0,
	0, 0, 0, 434, 375, 0, 378, 450, 0, 449,
	453, 451, 455, 0, 0, 0, 83, 0, 84, 91,
	79, 0, 94, 0, 0, 115, 0, 96, 0, 0,
	0, 115, 118, 98, 0, 0, 121, 129, 123, 124,
	125, 126, 127, 0, 0, 0, 0, 0, 287, 289,
	0, 136, 137, 138, 139, 0, 140, 0, 0, 0,
	141, 0, 312, 313, 314, 315, 316, 317, 318, 319,
	320, 321, 322, 323, 324, 325, 326, 327, 328, -2,
	-2, -2, -2, -2, -2, -2, -2, -2, 342, 0,
	0, 347, 105, 159, -2, 0, 0, 0, 150, 151,
	0, -2, 175, 179, 0, 239, 0, 0, 0, 205,
	0, 208, 122, 293, 0, 296, 297, 298, 299, 300,
	301, 302, 303, 304, 305, 306, 307, 0, 0, 0,
	431, 446, 0, 448, 0, -2, 0, 359, 463, 460,
	461, 0, 0, 0, 0, 417, 0, 0, 0, -2,
	-2, 0, 76, 77, 69, 70, 71, 72, 73, 74,
	75, 2, 3, 4, 5, 6, 7, 8, 9, 10,
	11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
	21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
	31, 32, 33, 34, 35, 36, 37, 38, 39, 40,
	41, 42, 43, 44, 45, 46, 47, 48, 49, 50,
	51, 52, 53, 54, 55, 56, 57, 58, 59, 60,
	61, 62, 63, 64, 65, 66, 67, 68, 0, -2,
	-2, 291, 389, 0, 414, 0, 0, 0, 175, 105,
	482, 484, 0, 0, 403, 406, 405, 0, 225, 105,
	227, 229, 0, 0, 391, 450, 0, -2, 450, 81,
	90, 0, 93, 95, 97, 0, 115, 111, 0, 115,
	0, 116, 0, 119, 282, 0, 0, 0, 286, 0,
	0, 231, 234, -2, 237, 283, 0, 346, 0, 106,
	0, 0, 153, -2, 0, 210, 212, 163, 217, 218,
	0, 220, 221, 222, 179, 0, 0, 176, 265, 239,
	178, 244, 0, 0, 0, 294, 0, 424, 426, 427,
	0, -2, 384, 0, 471, 472, 0, 474, 466, 467,
	468, 0, 470, 363, 425, 376, 0, 377, 441, 0,
	0, 440, 442, 179, 0, 106, 476, 479, 433, 0,
	106, 230, 390, 452, 454, 0, 0, 0, 92, 0,
	0, 105, 108, 113, 0, 0, 0, 132, 200, 122,
	0, 0, 288, 135, 195, 195, 0, 345, 0, 160,
	0, -2, 0, 0, 450, 147, 189, 122, 157, 0,
	369, 216, 165, 164, 219, 0, 239, 180, 173, 238,
	0, 0, 0, -2, 264, 267, 269, 270, 271, 272,
	273, 274, 265, 0, 0, 0, 0, 202, 122, 447,
	465, 473, 0, 444, 438, 439, 0, 475, 483, 226,
	228, -2, 450, 459, 105, 110, 0, 0, 106, 114,
	105, 128, 0, 0, 286, 0, 195, 0, 195, 369,
	144, 0, 0, -2, 450, 0, 0, 149, 0, 0,
	223, 223, 0, 213, 0, 166, 239, 265, 0, 276,
	277, 0, 367, 0, 268, 174, 245, 203, 122, 209,
	206, 0, 239, 0, 0, 106, 105, 103, 107, 0,
	0, 133, 0, 191, 0, 0, 0, 0, 0, 223,
	145, 187, 122, 0, 0, -2, 0, 0, 122, 0,
	0, 0, 0, 214, 265, 168, 240, 0, 0, 0,
	280, 0, 0, 242, 246, 0, 207, 469, 265, 458,
	101, 109, 0, 104, 201, 0, 0, 122, 198, 199,
	192, 193, 0, 0, 0, 0, 183, 190, 0, 155,
	0, 122, 224, 122, 0, 372, 373, 0, 0, 167,
	275, 278, 241, 0, 0, 0, 247, 0, 249, 0,
	0, 259, 0, 0, 258, 57, -2, 290, 102, 134,
	185, 122, 122, 197, 194, 122, 0, 146, 0, 0,
	158, 0, 0, 370, 0, 374, 215, 279, 281, -2,
	248, 250, 251, 252, 0, 0, 0, 0, 196, 0,
	188, 0, 156, 162, 365, 371, 0, 253, 254, 255,
	257, 260, 0, 366, 122, 223, 256, 186, 0, 0,
	154, 243, 261, 122, 0, 262,
}
var yyTok1 = [...]int{

	1, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 55, 166, 3, 167, 54, 37, 3,
	159, 160, 52, 49, 9, 50, 51, 53, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 31, 161,
	43, 17, 45, 30, 67, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 69, 3, 164, 36, 3, 165, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 162, 35, 163, 57,
}
var yyTok2 = [...]int{

	2, 3, 4, 5, 6, 7, 8, 10, 11, 12,
	13, 14, 15, 16, 18, 19, 20, 21, 22, 23,
	24, 25, 26, 27, 28, 29, 32, 33, 34, 38,
	39, 40, 41, 42, 44, 46, 47, 48, 56, 58,
	59, 60, 61, 62, 63, 64, 65, 66, 68, 70,
	71, 72, 73, 74, 75, 76, 77, 78, 79, 80,
	81, 82, 83, 84, 85, 86, 87, 88, 89, 90,
	91, 92, 93, 94, 95, 96, 97, 98, 99, 100,
	101, 102, 103, 104, 105, 106, 107, 108, 109, 110,
	111, 112, 113, 114, 115, 116, 117, 118, 119, 120,
	121, 122, 123, 124, 125, 126, 127, 128, 129, 130,
	131, 132, 133, 134, 135, 136, 137, 138, 139, 140,
	141, 142, 143, 144, 145, 146, 147, 148, 149, 150,
	151, 152, 153, 154, 155, 156, 157, 158,
}
var yyTok3 = [...]int{
	0,
}

var yyErrorMessages = [...]struct {
	state int
	token int
	msg   string
}{}

//line yaccpar:1

/*	parser for yacc output	*/

var (
	yyDebug        = 0
	yyErrorVerbose = false
)

type yyLexer interface {
	Lex(lval *yySymType) int
	Error(s string)
}

type yyParser interface {
	Parse(yyLexer) int
	Lookahead() int
}

type yyParserImpl struct {
	lval  yySymType
	stack [yyInitialStackSize]yySymType
	char  int
}

func (p *yyParserImpl) Lookahead() int {
	return p.char
}

func yyNewParser() yyParser {
	return &yyParserImpl{}
}

const yyFlag = -1000

func yyTokname(c int) string {
	if c >= 1 && c-1 < len(yyToknames) {
		if yyToknames[c-1] != "" {
			return yyToknames[c-1]
		}
	}
	return __yyfmt__.Sprintf("tok-%v", c)
}

func yyStatname(s int) string {
	if s >= 0 && s < len(yyStatenames) {
		if yyStatenames[s] != "" {
			return yyStatenames[s]
		}
	}
	return __yyfmt__.Sprintf("state-%v", s)
}

func yyErrorMessage(state, lookAhead int) string {
	const TOKSTART = 4

	if !yyErrorVerbose {
		return "syntax error"
	}

	for _, e := range yyErrorMessages {
		if e.state == state && e.token == lookAhead {
			return "syntax error: " + e.msg
		}
	}

	res := "syntax error: unexpected " + yyTokname(lookAhead)

	// To match Bison, suggest at most four expected tokens.
	expected := make([]int, 0, 4)

	// Look for shiftable tokens.
	base := yyPact[state]
	for tok := TOKSTART; tok-1 < len(yyToknames); tok++ {
		if n := base + tok; n >= 0 && n < yyLast && yyChk[yyAct[n]] == tok {
			if len(expected) == cap(expected) {
				return res
			}
			expected = append(expected, tok)
		}
	}

	if yyDef[state] == -2 {
		i := 0
		for yyExca[i] != -1 || yyExca[i+1] != state {
			i += 2
		}

		// Look for tokens that we accept or reduce.
		for i += 2; yyExca[i] >= 0; i += 2 {
			tok := yyExca[i]
			if tok < TOKSTART || yyExca[i+1] == 0 {
				continue
			}
			if len(expected) == cap(expected) {
				return res
			}
			expected = append(expected, tok)
		}

		// If the default action is to accept or reduce, give up.
		if yyExca[i+1] != 0 {
			return res
		}
	}

	for i, tok := range expected {
		if i == 0 {
			res += ", expecting "
		} else {
			res += " or "
		}
		res += yyTokname(tok)
	}
	return res
}

func yylex1(lex yyLexer, lval *yySymType) (char, token int) {
	token = 0
	char = lex.Lex(lval)
	if char <= 0 {
		token = yyTok1[0]
		goto out
	}
	if char < len(yyTok1) {
		token = yyTok1[char]
		goto out
	}
	if char >= yyPrivate {
		if char < yyPrivate+len(yyTok2) {
			token = yyTok2[char-yyPrivate]
			goto out
		}
	}
	for i := 0; i < len(yyTok3); i += 2 {
		token = yyTok3[i+0]
		if token == char {
			token = yyTok3[i+1]
			goto out
		}
	}

out:
	if token == 0 {
		token = yyTok2[1] /* unknown char */
	}
	if yyDebug >= 3 {
		__yyfmt__.Printf("lex %s(%d)\n", yyTokname(token), uint(char))
	}
	return char, token
}

func yyParse(yylex yyLexer) int {
	return yyNewParser().Parse(yylex)
}

func (yyrcvr *yyParserImpl) Parse(yylex yyLexer) int {
	var yyn int
	var yyVAL yySymType
	var yyDollar []yySymType
	_ = yyDollar // silence set and not used
	yyS := yyrcvr.stack[:]

	Nerrs := 0   /* number of errors */
	Errflag := 0 /* error recovery flag */
	yystate := 0
	yyrcvr.char = -1
	yytoken := -1 // yyrcvr.char translated into internal numbering
	defer func() {
		// Make sure we report no lookahead when not parsing.
		yystate = -1
		yyrcvr.char = -1
		yytoken = -1
	}()
	yyp := -1
	goto yystack

ret0:
	return 0

ret1:
	return 1

yystack:
	/* put a state and value onto the stack */
	if yyDebug >= 4 {
		__yyfmt__.Printf("char %v in %v\n", yyTokname(yytoken), yyStatname(yystate))
	}

	yyp++
	if yyp >= len(yyS) {
		nyys := make([]yySymType, len(yyS)*2)
		copy(nyys, yyS)
		yyS = nyys
	}
	yyS[yyp] = yyVAL
	yyS[yyp].yys = yystate

yynewstate:
	yyn = yyPact[yystate]
	if yyn <= yyFlag {
		goto yydefault /* simple state */
	}
	if yyrcvr.char < 0 {
		yyrcvr.char, yytoken = yylex1(yylex, &yyrcvr.lval)
	}
	yyn += yytoken
	if yyn < 0 || yyn >= yyLast {
		goto yydefault
	}
	yyn = yyAct[yyn]
	if yyChk[yyn] == yytoken { /* valid shift */
		yyrcvr.char = -1
		yytoken = -1
		yyVAL = yyrcvr.lval
		yystate = yyn
		if Errflag > 0 {
			Errflag--
		}
		goto yystack
	}

yydefault:
	/* default state action */
	yyn = yyDef[yystate]
	if yyn == -2 {
		if yyrcvr.char < 0 {
			yyrcvr.char, yytoken = yylex1(yylex, &yyrcvr.lval)
		}

		/* look through exception table */
		xi := 0
		for {
			if yyExca[xi+0] == -1 && yyExca[xi+1] == yystate {
				break
			}
			xi += 2
		}
		for xi += 2; ; xi += 2 {
			yyn = yyExca[xi+0]
			if yyn < 0 || yyn == yytoken {
				break
			}
		}
		yyn = yyExca[xi+1]
		if yyn < 0 {
			goto ret0
		}
	}
	if yyn == 0 {
		/* error ... attempt to resume parsing */
		switch Errflag {
		case 0: /* brand new error */
			yylex.Error(yyErrorMessage(yystate, yytoken))
			Nerrs++
			if yyDebug >= 1 {
				__yyfmt__.Printf("%s", yyStatname(yystate))
				__yyfmt__.Printf(" saw %s\n", yyTokname(yytoken))
			}
			fallthrough

		case 1, 2: /* incompletely recovered error ... try again */
			Errflag = 3

			/* find a state where "error" is a legal shift action */
			for yyp >= 0 {
				yyn = yyPact[yyS[yyp].yys] + yyErrCode
				if yyn >= 0 && yyn < yyLast {
					yystate = yyAct[yyn] /* simulate a shift of "error" */
					if yyChk[yystate] == yyErrCode {
						goto yystack
					}
				}

				/* the current p has no shift on "error", pop stack */
				if yyDebug >= 2 {
					__yyfmt__.Printf("error recovery pops state %d\n", yyS[yyp].yys)
				}
				yyp--
			}
			/* there is no state on the stack with an error shift ... abort */
			goto ret1

		case 3: /* no shift yet; clobber input char */
			if yyDebug >= 2 {
				__yyfmt__.Printf("error recovery discards %s\n", yyTokname(yytoken))
			}
			if yytoken == yyEofCode {
				goto ret1
			}
			yyrcvr.char = -1
			yytoken = -1
			goto yynewstate /* try again in the same state */
		}
	}

	/* reduction by production yyn */
	if yyDebug >= 2 {
		__yyfmt__.Printf("reduce %v in:\n\t%v\n", yyn, yyStatname(yystate))
	}

	yynt := yyn
	yypt := yyp
	_ = yypt // guard against "declared and not used"

	yyp -= yyR2[yyn]
	// yyp is now the index of $0. Perform the default action. Iff the
	// reduced production is ε, $1 is possibly out of range.
	if yyp+1 >= len(yyS) {
		nyys := make([]yySymType, len(yyS)*2)
		copy(nyys, yyS)
		yyS = nyys
	}
	yyVAL = yyS[yyp+1]

	/* consult goto table to find next state */
	yyn = yyR1[yyn]
	yyg := yyPgo[yyn]
	yyj := yyg + yyS[yyp].yys + 1

	if yyj >= yyLast {
		yystate = yyAct[yyg]
	} else {
		yystate = yyAct[yyj]
		if yyChk[yystate] != -yyn {
			yystate = yyAct[yyg]
		}
	}
	// dummy call; replaced with literal code
	switch yynt {

	case 1:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:322
		{
			fmt.Println(yyDollar[1].node)
		}
	case 2:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:326
		{
			yyVAL.value = yyDollar[1].token
		}
	case 3:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:326
		{
			yyVAL.value = yyDollar[1].token
		}
	case 4:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:326
		{
			yyVAL.value = yyDollar[1].token
		}
	case 5:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:326
		{
			yyVAL.value = yyDollar[1].token
		}
	case 6:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:326
		{
			yyVAL.value = yyDollar[1].token
		}
	case 7:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:326
		{
			yyVAL.value = yyDollar[1].token
		}
	case 8:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:326
		{
			yyVAL.value = yyDollar[1].token
		}
	case 9:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:326
		{
			yyVAL.value = yyDollar[1].token
		}
	case 10:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:327
		{
			yyVAL.value = yyDollar[1].token
		}
	case 11:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:327
		{
			yyVAL.value = yyDollar[1].token
		}
	case 12:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:327
		{
			yyVAL.value = yyDollar[1].token
		}
	case 13:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:327
		{
			yyVAL.value = yyDollar[1].token
		}
	case 14:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:327
		{
			yyVAL.value = yyDollar[1].token
		}
	case 15:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:327
		{
			yyVAL.value = yyDollar[1].token
		}
	case 16:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:327
		{
			yyVAL.value = yyDollar[1].token
		}
	case 17:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:327
		{
			yyVAL.value = yyDollar[1].token
		}
	case 18:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:327
		{
			yyVAL.value = yyDollar[1].token
		}
	case 19:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:327
		{
			yyVAL.value = yyDollar[1].token
		}
	case 20:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:327
		{
			yyVAL.value = yyDollar[1].token
		}
	case 21:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:327
		{
			yyVAL.value = yyDollar[1].token
		}
	case 22:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:328
		{
			yyVAL.value = yyDollar[1].token
		}
	case 23:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:328
		{
			yyVAL.value = yyDollar[1].token
		}
	case 24:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:328
		{
			yyVAL.value = yyDollar[1].token
		}
	case 25:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:328
		{
			yyVAL.value = yyDollar[1].token
		}
	case 26:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:328
		{
			yyVAL.value = yyDollar[1].token
		}
	case 27:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:328
		{
			yyVAL.value = yyDollar[1].token
		}
	case 28:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:328
		{
			yyVAL.value = yyDollar[1].token
		}
	case 29:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:328
		{
			yyVAL.value = yyDollar[1].token
		}
	case 30:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:328
		{
			yyVAL.value = yyDollar[1].token
		}
	case 31:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:328
		{
			yyVAL.value = yyDollar[1].token
		}
	case 32:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:329
		{
			yyVAL.value = yyDollar[1].token
		}
	case 33:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:329
		{
			yyVAL.value = yyDollar[1].token
		}
	case 34:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:329
		{
			yyVAL.value = yyDollar[1].token
		}
	case 35:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:329
		{
			yyVAL.value = yyDollar[1].token
		}
	case 36:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:329
		{
			yyVAL.value = yyDollar[1].token
		}
	case 37:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:329
		{
			yyVAL.value = yyDollar[1].token
		}
	case 38:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:329
		{
			yyVAL.value = yyDollar[1].token
		}
	case 39:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:329
		{
			yyVAL.value = yyDollar[1].token
		}
	case 40:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:329
		{
			yyVAL.value = yyDollar[1].token
		}
	case 41:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:329
		{
			yyVAL.value = yyDollar[1].token
		}
	case 42:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:330
		{
			yyVAL.value = yyDollar[1].token
		}
	case 43:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:330
		{
			yyVAL.value = yyDollar[1].token
		}
	case 44:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:330
		{
			yyVAL.value = yyDollar[1].token
		}
	case 45:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:330
		{
			yyVAL.value = yyDollar[1].token
		}
	case 46:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:330
		{
			yyVAL.value = yyDollar[1].token
		}
	case 47:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:330
		{
			yyVAL.value = yyDollar[1].token
		}
	case 48:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:330
		{
			yyVAL.value = yyDollar[1].token
		}
	case 49:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:330
		{
			yyVAL.value = yyDollar[1].token
		}
	case 50:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:330
		{
			yyVAL.value = yyDollar[1].token
		}
	case 51:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:330
		{
			yyVAL.value = yyDollar[1].token
		}
	case 52:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:330
		{
			yyVAL.value = yyDollar[1].token
		}
	case 53:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:331
		{
			yyVAL.value = yyDollar[1].token
		}
	case 54:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:331
		{
			yyVAL.value = yyDollar[1].token
		}
	case 55:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:331
		{
			yyVAL.value = yyDollar[1].token
		}
	case 56:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:331
		{
			yyVAL.value = yyDollar[1].token
		}
	case 57:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:331
		{
			yyVAL.value = yyDollar[1].token
		}
	case 58:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:331
		{
			yyVAL.value = yyDollar[1].token
		}
	case 59:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:331
		{
			yyVAL.value = yyDollar[1].token
		}
	case 60:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:331
		{
			yyVAL.value = yyDollar[1].token
		}
	case 61:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:332
		{
			yyVAL.value = yyDollar[1].token
		}
	case 62:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:332
		{
			yyVAL.value = yyDollar[1].token
		}
	case 63:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:332
		{
			yyVAL.value = yyDollar[1].token
		}
	case 64:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:332
		{
			yyVAL.value = yyDollar[1].token
		}
	case 65:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:332
		{
			yyVAL.value = yyDollar[1].token
		}
	case 66:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:332
		{
			yyVAL.value = yyDollar[1].token
		}
	case 67:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:332
		{
			yyVAL.value = yyDollar[1].token
		}
	case 68:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:332
		{
			yyVAL.value = yyDollar[1].token
		}
	case 69:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:336
		{
			yyVAL.value = yyDollar[1].value
		}
	case 70:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:337
		{
			yyVAL.value = yyDollar[1].token
		}
	case 71:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:337
		{
			yyVAL.value = yyDollar[1].token
		}
	case 72:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:337
		{
			yyVAL.value = yyDollar[1].token
		}
	case 73:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:337
		{
			yyVAL.value = yyDollar[1].token
		}
	case 74:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:337
		{
			yyVAL.value = yyDollar[1].token
		}
	case 75:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:337
		{
			yyVAL.value = yyDollar[1].token
		}
	case 76:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:341
		{
			yyVAL.node = Node("identifier").attribute("value", yyDollar[1].token)
		}
	case 77:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:342
		{
			yyVAL.node = Node("identifier").attribute("value", yyDollar[1].value)
		}
	case 78:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:346
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[2].node)
		}
	case 79:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:347
		{
			yyVAL.node = Node("Statements")
		}
	case 80:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:351
		{
			yyVAL.node = Node("NamespaceParts").append(Node(yyDollar[1].token))
		}
	case 81:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:352
		{
			yyVAL.node = yyDollar[1].node.append(Node(yyDollar[3].token))
		}
	case 82:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:356
		{
			yyVAL.node = Node("Name").append(yyDollar[1].node)
		}
	case 83:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:357
		{
			yyVAL.node = Node("Name").append(yyDollar[2].node).attribute("FullyQualified", "true")
		}
	case 84:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:358
		{
			yyVAL.node = Node("Name").append(yyDollar[3].node).attribute("Relative", "true")
		}
	case 85:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:362
		{
			yyVAL.node = yyDollar[1].node
		}
	case 86:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:363
		{
			yyVAL.node = yyDollar[1].node
		}
	case 87:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:364
		{
			yyVAL.node = yyDollar[1].node
		}
	case 88:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:365
		{
			yyVAL.node = yyDollar[1].node
		}
	case 89:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:366
		{
			yyVAL.node = yyDollar[1].node
		}
	case 90:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:367
		{
			yyVAL.node = Node("THaltCompiler")
		}
	case 91:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:368
		{
			yyVAL.node = Node("Namespace").append(yyDollar[2].node)
		}
	case 92:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:370
		{
			yyVAL.node = Node("Namespace").append(yyDollar[2].node).append(yyDollar[4].node)
		}
	case 93:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:371
		{
			yyVAL.node = Node("Namespace").append(yyDollar[3].node)
		}
	case 94:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:372
		{
			yyVAL.node = yyDollar[2].node
		}
	case 95:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:373
		{
			yyVAL.node = yyDollar[3].node.append(yyDollar[2].node)
		}
	case 96:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:374
		{
			yyVAL.node = yyDollar[2].node
		}
	case 97:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:375
		{
			yyVAL.node = yyDollar[3].node.append(yyDollar[2].node)
		}
	case 98:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:376
		{
			yyVAL.node = yyDollar[2].node
		}
	case 99:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:380
		{
			yyVAL.node = Node("FuncUseType")
		}
	case 100:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:381
		{
			yyVAL.node = Node("ConstUseType")
		}
	case 101:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:386
		{
			yyVAL.node = Node("GroupUse").append(yyDollar[1].node).append(yyDollar[4].node)
		}
	case 102:
		yyDollar = yyS[yypt-7 : yypt+1]
		//line parser.y:388
		{
			yyVAL.node = Node("GroupUse").append(yyDollar[2].node).append(yyDollar[5].node)
		}
	case 103:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:393
		{
			yyVAL.node = Node("MixedGroupUse").append(yyDollar[1].node).append(yyDollar[4].node)
		}
	case 104:
		yyDollar = yyS[yypt-7 : yypt+1]
		//line parser.y:395
		{
			yyVAL.node = Node("MixedGroupUse").append(yyDollar[2].node).append(yyDollar[5].node)
		}
	case 107:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:405
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 108:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:406
		{
			yyVAL.node = Node("UseList").append(yyDollar[1].node)
		}
	case 109:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:411
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 110:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:412
		{
			yyVAL.node = Node("UseList").append(yyDollar[1].node)
		}
	case 111:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:416
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 112:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:417
		{
			yyVAL.node = Node("UseList").append(yyDollar[1].node)
		}
	case 113:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:421
		{
			yyVAL.node = yyDollar[1].node
		}
	case 114:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:422
		{
			yyVAL.node = yyDollar[2].node.append(yyDollar[1].node)
		}
	case 115:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:426
		{
			yyVAL.node = Node("UseElem").append(yyDollar[1].node)
		}
	case 116:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:427
		{
			yyVAL.node = Node("UseElem").append(yyDollar[1].node).append(Node("as").attribute("value", yyDollar[3].token))
		}
	case 117:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:431
		{
			yyVAL.node = yyDollar[1].node
		}
	case 118:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:432
		{
			yyVAL.node = yyDollar[2].node
		}
	case 119:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:436
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 120:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:437
		{
			yyVAL.node = Node("ConstList").append(yyDollar[1].node)
		}
	case 121:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:441
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[2].node)
		}
	case 122:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:442
		{
			yyVAL.node = Node("stmt")
		}
	case 123:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:446
		{
			yyVAL.node = yyDollar[1].node
		}
	case 124:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:447
		{
			yyVAL.node = yyDollar[1].node
		}
	case 125:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:448
		{
			yyVAL.node = yyDollar[1].node
		}
	case 126:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:449
		{
			yyVAL.node = yyDollar[1].node
		}
	case 127:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:450
		{
			yyVAL.node = yyDollar[1].node
		}
	case 128:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:451
		{
			yyVAL.node = Node("THaltCompiler")
		}
	case 129:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:454
		{
			yyVAL.node = yyDollar[2].node
		}
	case 130:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:455
		{
			yyVAL.node = yyDollar[1].node
		}
	case 131:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:456
		{
			yyVAL.node = yyDollar[1].node
		}
	case 132:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:458
		{
			yyVAL.node = Node("While").
				append(Node("expr").append(yyDollar[3].node)).
				append(Node("stmt").append(yyDollar[5].node))
		}
	case 133:
		yyDollar = yyS[yypt-7 : yypt+1]
		//line parser.y:464
		{
			yyVAL.node = Node("DoWhile").
				append(Node("expr").append(yyDollar[5].node)).
				append(Node("stmt").append(yyDollar[2].node))
		}
	case 134:
		yyDollar = yyS[yypt-9 : yypt+1]
		//line parser.y:470
		{
			yyVAL.node = Node("For").
				append(Node("expr1").append(yyDollar[3].node)).
				append(Node("expr2").append(yyDollar[5].node)).
				append(Node("expr3").append(yyDollar[7].node)).
				append(Node("stmt").append(yyDollar[9].node))
		}
	case 135:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:477
		{
			yyVAL.node = Node("Switch").append(Node("expr").append(yyDollar[3].node)).append(yyDollar[5].node)
		}
	case 136:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:478
		{
			yyVAL.node = Node("Break").append(yyDollar[2].node)
		}
	case 137:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:479
		{
			yyVAL.node = Node("Continue").append(yyDollar[2].node)
		}
	case 138:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:480
		{
			yyVAL.node = Node("Return").append(yyDollar[2].node)
		}
	case 139:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:481
		{
			yyVAL.node = yyDollar[2].node
		}
	case 140:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:482
		{
			yyVAL.node = yyDollar[2].node
		}
	case 141:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:483
		{
			yyVAL.node = yyDollar[2].node
		}
	case 142:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:484
		{
			yyVAL.node = Node("Echo").append(Node("InlineHtml").attribute("value", yyDollar[1].token))
		}
	case 143:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:485
		{
			yyVAL.node = yyDollar[1].node
		}
	case 144:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:487
		{
			yyVAL.node = Node("Unset").append(yyDollar[3].node)
		}
	case 145:
		yyDollar = yyS[yypt-7 : yypt+1]
		//line parser.y:489
		{
			yyVAL.node = Node("Foreach").
				append(Node("expr").append(yyDollar[3].node)).
				append(Node("ForeachVariable").append(yyDollar[5].node)).
				append(yyDollar[7].node)
		}
	case 146:
		yyDollar = yyS[yypt-9 : yypt+1]
		//line parser.y:496
		{
			yyVAL.node = Node("Foreach").
				append(Node("expr").append(yyDollar[3].node)).
				append(Node("ForeachKey").append(yyDollar[5].node)).
				append(Node("ForeachVariable").append(yyDollar[7].node)).
				append(yyDollar[9].node)
		}
	case 147:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:503
		{
			yyVAL.node = Node("Declare").append(yyDollar[3].node).append(yyDollar[5].node)
		}
	case 148:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:504
		{
			yyVAL.node = Node("")
		}
	case 149:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:506
		{
			yyVAL.node = Node("Try").
				append(yyDollar[3].node).
				append(yyDollar[5].node).
				append(yyDollar[6].node)
		}
	case 150:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:512
		{
			yyVAL.node = Node("Throw").append(yyDollar[2].node)
		}
	case 151:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:513
		{
			yyVAL.node = Node("GoTo").attribute("Label", yyDollar[2].token)
		}
	case 152:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:514
		{
			yyVAL.node = Node("Label").attribute("name", yyDollar[1].token)
		}
	case 153:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:517
		{
			yyVAL.node = Node("CatchList")
		}
	case 154:
		yyDollar = yyS[yypt-9 : yypt+1]
		//line parser.y:519
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[4].node).append(Node("Variable").attribute("name", yyDollar[5].token)).append(yyDollar[8].node)
		}
	case 155:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:522
		{
			yyVAL.node = Node("CatchNameList").append(yyDollar[1].node)
		}
	case 156:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:523
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 157:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:527
		{
			yyVAL.node = Node("")
		}
	case 158:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:528
		{
			yyVAL.node = Node("Finnaly").append(yyDollar[3].node)
		}
	case 159:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:532
		{
			yyVAL.node = Node("UnsetVariablesList").append(yyDollar[1].node)
		}
	case 160:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:533
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 161:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:537
		{
			yyVAL.node = yyDollar[1].node
		}
	case 162:
		yyDollar = yyS[yypt-10 : yypt+1]
		//line parser.y:542
		{
			yyVAL.node = Node("Function").
				attribute("name", yyDollar[3].token).
				attribute("returns_ref", yyDollar[2].value).
				append(yyDollar[5].node).
				append(yyDollar[7].node).
				append(yyDollar[9].node)
		}
	case 163:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:553
		{
			yyVAL.value = "false"
		}
	case 164:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:554
		{
			yyVAL.value = "true"
		}
	case 165:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:558
		{
			yyVAL.value = "false"
		}
	case 166:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:559
		{
			yyVAL.value = "true"
		}
	case 167:
		yyDollar = yyS[yypt-8 : yypt+1]
		//line parser.y:564
		{
			yyVAL.node = Node("Class").
				attribute("name", yyDollar[3].token).
				append(yyDollar[1].node).
				append(Node("Extends").append(yyDollar[4].node)).
				append(Node("Implements").append(yyDollar[5].node)).
				append(yyDollar[7].node)
		}
	case 168:
		yyDollar = yyS[yypt-7 : yypt+1]
		//line parser.y:573
		{
			yyVAL.node = Node("Class").
				attribute("name", yyDollar[2].token).
				append(Node("Extends").append(yyDollar[3].node)).
				append(Node("Implements").append(yyDollar[4].node)).
				append(yyDollar[6].node)
		}
	case 169:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:583
		{
			yyVAL.node = Node("Class").attribute(yyDollar[1].value, "true")
		}
	case 170:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:584
		{
			yyVAL.node = yyDollar[1].node.attribute(yyDollar[2].value, "true")
		}
	case 171:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:588
		{
			yyVAL.value = "abstract"
		}
	case 172:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:589
		{
			yyVAL.value = "final"
		}
	case 173:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:593
		{
			yyVAL.node = Node("Trait").attribute("name", yyDollar[2].token).append(yyDollar[4].node)
		}
	case 174:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:598
		{
			yyVAL.node = Node("Interface").
				attribute("name", yyDollar[2].token).
				append(Node("Extends").append(yyDollar[3].node)).
				append(yyDollar[5].node)
		}
	case 175:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:607
		{
			yyVAL.node = Node("")
		}
	case 176:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:608
		{
			yyVAL.node = yyDollar[2].node
		}
	case 177:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:612
		{
			yyVAL.node = Node("")
		}
	case 178:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:613
		{
			yyVAL.node = yyDollar[2].node
		}
	case 179:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:617
		{
			yyVAL.node = Node("")
		}
	case 180:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:618
		{
			yyVAL.node = yyDollar[2].node
		}
	case 181:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:622
		{
			yyVAL.node = yyDollar[1].node
		}
	case 182:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:623
		{
			yyVAL.node = Node("Ref").append(yyDollar[2].node)
		}
	case 183:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:624
		{
			yyVAL.node = Node("List").append(yyDollar[3].node)
		}
	case 184:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:625
		{
			yyVAL.node = Node("ShortList").append(yyDollar[2].node)
		}
	case 185:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:629
		{
			yyVAL.node = yyDollar[1].node
		}
	case 186:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:630
		{
			yyVAL.node = yyDollar[2].node
		}
	case 187:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:634
		{
			yyVAL.node = yyDollar[1].node
		}
	case 188:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:635
		{
			yyVAL.node = yyDollar[2].node
		}
	case 189:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:639
		{
			yyVAL.node = yyDollar[1].node
		}
	case 190:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:640
		{
			yyVAL.node = yyDollar[2].node
		}
	case 191:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:644
		{
			yyVAL.node = yyDollar[2].node
		}
	case 192:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:645
		{
			yyVAL.node = yyDollar[3].node
		}
	case 193:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:646
		{
			yyVAL.node = yyDollar[2].node
		}
	case 194:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:647
		{
			yyVAL.node = yyDollar[3].node
		}
	case 195:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:651
		{
			yyVAL.node = Node("CaseList")
		}
	case 196:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:653
		{
			yyVAL.node = yyDollar[1].node.append(Node("Case").append(Node("expr").append(yyDollar[3].node)).append(yyDollar[5].node))
		}
	case 197:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:657
		{
			yyVAL.node = yyDollar[1].node.append(Node("Default").append(yyDollar[4].node))
		}
	case 200:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:668
		{
			yyVAL.node = yyDollar[1].node
		}
	case 201:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:669
		{
			yyVAL.node = yyDollar[2].node
		}
	case 202:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:674
		{
			yyVAL.node = Node("If").append(Node("expr").append(yyDollar[3].node)).append(Node("stmt").append(yyDollar[5].node))
		}
	case 203:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:678
		{
			yyVAL.node = yyDollar[1].node.append(Node("ElseIf").append(Node("expr").append(yyDollar[4].node)).append(Node("stmt").append(yyDollar[6].node)))
		}
	case 204:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:684
		{
			yyVAL.node = yyDollar[1].node
		}
	case 205:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:686
		{
			yyVAL.node = yyDollar[1].node.append(Node("Else").append(Node("stmt").append(yyDollar[3].node)))
		}
	case 206:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:693
		{
			yyVAL.node = Node("AltIf").append(Node("expr").append(yyDollar[3].node)).append(Node("stmt").append(yyDollar[6].node))
		}
	case 207:
		yyDollar = yyS[yypt-7 : yypt+1]
		//line parser.y:697
		{
			yyVAL.node = yyDollar[1].node.append(Node("AltElseIf").append(Node("expr").append(yyDollar[4].node)).append(Node("stmt").append(yyDollar[7].node)))
		}
	case 208:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:703
		{
			yyVAL.node = yyDollar[1].node
		}
	case 209:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:705
		{
			yyVAL.node = yyDollar[1].node.append(Node("AltElse").append(Node("stmt").append(yyDollar[4].node)))
		}
	case 210:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:711
		{
			yyVAL.node = yyDollar[1].node
		}
	case 211:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:712
		{
			yyVAL.node = Node("Parameter list")
		}
	case 212:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:716
		{
			yyVAL.node = Node("Parameter list").append(yyDollar[1].node)
		}
	case 213:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:717
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 214:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:722
		{
			yyVAL.node = Node("Parameter").
				append(yyDollar[1].node).
				attribute("is_reference", yyDollar[2].value).
				attribute("is_variadic", yyDollar[3].value).
				attribute("var", yyDollar[4].token)
		}
	case 215:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:730
		{
			yyVAL.node = Node("Parameter").
				append(yyDollar[1].node).
				attribute("is_reference", yyDollar[2].value).
				attribute("is_variadic", yyDollar[3].value).
				attribute("var", yyDollar[4].token).
				append(yyDollar[6].node)
		}
	case 216:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:741
		{
			yyVAL.node = Node("No type")
		}
	case 217:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:742
		{
			yyVAL.node = yyDollar[1].node
		}
	case 218:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:746
		{
			yyVAL.node = yyDollar[1].node
		}
	case 219:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:747
		{
			yyVAL.node = yyDollar[2].node
			yyVAL.node.attribute("nullable", "true")
		}
	case 220:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:751
		{
			yyVAL.node = yyDollar[1].node
		}
	case 221:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:752
		{
			yyVAL.node = Node("array type")
		}
	case 222:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:753
		{
			yyVAL.node = Node("callable type")
		}
	case 223:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:757
		{
			yyVAL.node = Node("No return type")
		}
	case 224:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:758
		{
			yyVAL.node = yyDollar[2].node
		}
	case 225:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:762
		{
			yyVAL.node = Node("ArgumentList")
		}
	case 226:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:763
		{
			yyVAL.node = yyDollar[2].node
		}
	case 227:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:767
		{
			yyVAL.node = Node("ArgumentList").append(yyDollar[1].node)
		}
	case 228:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:768
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 229:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:772
		{
			yyVAL.node = yyDollar[1].node
		}
	case 230:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:773
		{
			yyVAL.node = Node("Unpack").append(yyDollar[2].node)
		}
	case 231:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:777
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 232:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:778
		{
			yyVAL.node = Node("GlobalVarList").append(yyDollar[1].node)
		}
	case 233:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:782
		{
			yyVAL.node = yyDollar[1].node
		}
	case 234:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:786
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 235:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:787
		{
			yyVAL.node = Node("StaticVarList").append(yyDollar[1].node)
		}
	case 236:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:791
		{
			yyVAL.node = Node("StaticVariable").attribute("Name", yyDollar[1].token)
		}
	case 237:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:792
		{
			yyVAL.node = Node("StaticVariable").attribute("Name", yyDollar[1].token).append(Node("expr").append(yyDollar[3].node))
		}
	case 238:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:796
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[2].node)
		}
	case 239:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:797
		{
			yyVAL.node = Node("Stmt")
		}
	case 240:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:801
		{
			yyVAL.node = yyDollar[2].node.append(yyDollar[1].node)
		}
	case 241:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:802
		{
			yyVAL.node = yyDollar[3].node.append(yyDollar[1].node)
		}
	case 242:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:803
		{
			yyVAL.node = Node("Use").append(yyDollar[2].node).append(yyDollar[3].node)
		}
	case 243:
		yyDollar = yyS[yypt-9 : yypt+1]
		//line parser.y:806
		{
			yyVAL.node = Node("Function").
				append(yyDollar[1].node).
				append(Node("name").append(yyDollar[4].node)).
				attribute("returns_ref", yyDollar[3].value).
				append(yyDollar[6].node).
				append(yyDollar[8].node).
				append(yyDollar[9].node)
		}
	case 244:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:818
		{
			yyVAL.node = Node("NameList").append(yyDollar[1].node)
		}
	case 245:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:819
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 246:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:823
		{
			yyVAL.node = Node("")
		}
	case 247:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:824
		{
			yyVAL.node = Node("")
		}
	case 248:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:825
		{
			yyVAL.node = yyDollar[2].node
		}
	case 249:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:829
		{
			yyVAL.node = Node("TraitAdaptionList").append(yyDollar[1].node)
		}
	case 250:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:830
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[2].node)
		}
	case 251:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:834
		{
			yyVAL.node = yyDollar[1].node
		}
	case 252:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:835
		{
			yyVAL.node = yyDollar[1].node
		}
	case 253:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:840
		{
			yyVAL.node = Node("TraitPrecedence").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 254:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:844
		{
			yyVAL.node = yyDollar[1].node.append(Node("as").attribute("value", yyDollar[3].token))
		}
	case 255:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:846
		{
			yyVAL.node = yyDollar[1].node.append(Node("as").append(Node("reservedNonModifiers")))
		}
	case 256:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:848
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node).append(yyDollar[4].node)
		}
	case 257:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:849
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 258:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:853
		{
			yyVAL.node = Node("TraitMethodRef").append(yyDollar[1].node)
		}
	case 259:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:854
		{
			yyVAL.node = yyDollar[1].node
		}
	case 260:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:858
		{
			yyVAL.node = Node("TraitMethodRef").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 261:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:862
		{
			yyVAL.node = Node("")
		}
	case 262:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:863
		{
			yyVAL.node = yyDollar[2].node
		}
	case 263:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:867
		{
			yyVAL.node = yyDollar[1].node
		}
	case 264:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:868
		{
			yyVAL.node = Node("VarMemberModifier")
		}
	case 265:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:872
		{
			yyVAL.node = Node("PublicMemberModifier")
		}
	case 266:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:873
		{
			yyVAL.node = yyDollar[1].node
		}
	case 267:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:877
		{
			yyVAL.node = yyDollar[1].node
		}
	case 268:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:878
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[2].node)
		}
	case 269:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:882
		{
			yyVAL.node = Node("PublicMemberModifier")
		}
	case 270:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:883
		{
			yyVAL.node = Node("ProtectedMemberModifier")
		}
	case 271:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:884
		{
			yyVAL.node = Node("PrivateMemberModifier")
		}
	case 272:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:885
		{
			yyVAL.node = Node("StaticMemberModifier")
		}
	case 273:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:886
		{
			yyVAL.node = Node("AbstractMemberModifier")
		}
	case 274:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:887
		{
			yyVAL.node = Node("FinalMemberModifier")
		}
	case 275:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:891
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 276:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:892
		{
			yyVAL.node = Node("PropertyList").append(yyDollar[1].node)
		}
	case 277:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:896
		{
			yyVAL.node = Node("Property").attribute("name", yyDollar[1].token)
		}
	case 278:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:897
		{
			yyVAL.node = Node("Property").attribute("name", yyDollar[1].token).append(Node("Default").append(yyDollar[3].node))
		}
	case 279:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:901
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 280:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:902
		{
			yyVAL.node = Node("ConstList").append(yyDollar[1].node)
		}
	case 281:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:906
		{
			yyVAL.node = Node("Const").append(yyDollar[3].node)
		}
	case 282:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:910
		{
			yyVAL.node = Node("Const").attribute("name", yyDollar[1].token).append(yyDollar[3].node)
		}
	case 283:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:914
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 284:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:915
		{
			yyVAL.node = Node("EchoList").append(yyDollar[1].node)
		}
	case 285:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:919
		{
			yyVAL.node = Node("Echo").append(yyDollar[1].node)
		}
	case 286:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:923
		{
			yyVAL.node = Node("")
		}
	case 287:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:924
		{
			yyVAL.node = yyDollar[1].node
		}
	case 288:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:927
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 289:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:928
		{
			yyVAL.node = Node("ExpressionList").append(yyDollar[1].node)
		}
	case 290:
		yyDollar = yyS[yypt-7 : yypt+1]
		//line parser.y:933
		{
			yyVAL.node = Node("AnonymousClass").
				attribute("name", yyDollar[1].token).
				append(yyDollar[2].node).
				append(yyDollar[3].node).
				append(yyDollar[4].node).
				append(yyDollar[6].node)
		}
	case 291:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:944
		{
			yyVAL.node = Node("New").append(yyDollar[2].node).append(yyDollar[3].node)
		}
	case 292:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:945
		{
			yyVAL.node = Node("New").append(yyDollar[2].node)
		}
	case 293:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:949
		{
			yyVAL.node = Node("Assign").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 294:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:950
		{
			yyVAL.node = Node("AssignRef").append(yyDollar[1].node).append(yyDollar[4].node)
		}
	case 295:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:951
		{
			yyVAL.node = Node("Clone").append(yyDollar[2].node)
		}
	case 296:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:952
		{
			yyVAL.node = Node("AssignAdd").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 297:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:953
		{
			yyVAL.node = Node("AssignSub").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 298:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:954
		{
			yyVAL.node = Node("AssignMul").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 299:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:955
		{
			yyVAL.node = Node("AssignPow").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 300:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:956
		{
			yyVAL.node = Node("AssignDiv").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 301:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:957
		{
			yyVAL.node = Node("AssignConcat").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 302:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:958
		{
			yyVAL.node = Node("AssignMod").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 303:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:959
		{
			yyVAL.node = Node("AssignAnd").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 304:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:960
		{
			yyVAL.node = Node("AssignOr").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 305:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:961
		{
			yyVAL.node = Node("AssignXor").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 306:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:962
		{
			yyVAL.node = Node("AssignShiftLeft").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 307:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:963
		{
			yyVAL.node = Node("AssignShiftRight").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 308:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:964
		{
			yyVAL.node = Node("PostIncrement").append(yyDollar[1].node)
		}
	case 309:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:965
		{
			yyVAL.node = Node("PreIncrement").append(yyDollar[2].node)
		}
	case 310:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:966
		{
			yyVAL.node = Node("PostDecrement").append(yyDollar[1].node)
		}
	case 311:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:967
		{
			yyVAL.node = Node("PreDecrement").append(yyDollar[2].node)
		}
	case 312:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:968
		{
			yyVAL.node = Node("Or").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 313:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:969
		{
			yyVAL.node = Node("And").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 314:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:970
		{
			yyVAL.node = Node("Or").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 315:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:971
		{
			yyVAL.node = Node("And").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 316:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:972
		{
			yyVAL.node = Node("Xor").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 317:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:973
		{
			yyVAL.node = Node("BitwiseOr").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 318:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:974
		{
			yyVAL.node = Node("BitwiseAnd").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 319:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:975
		{
			yyVAL.node = Node("BitwiseXor").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 320:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:976
		{
			yyVAL.node = Node("Concat").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 321:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:977
		{
			yyVAL.node = Node("Add").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 322:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:978
		{
			yyVAL.node = Node("Sub").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 323:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:979
		{
			yyVAL.node = Node("Mul").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 324:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:980
		{
			yyVAL.node = Node("Pow").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 325:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:981
		{
			yyVAL.node = Node("Div").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 326:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:982
		{
			yyVAL.node = Node("Mod").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 327:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:983
		{
			yyVAL.node = Node("ShiftLeft").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 328:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:984
		{
			yyVAL.node = Node("ShiftRight").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 329:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:985
		{
			yyVAL.node = Node("UnaryPlus").append(yyDollar[2].node)
		}
	case 330:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:986
		{
			yyVAL.node = Node("UnaryMinus").append(yyDollar[2].node)
		}
	case 331:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:987
		{
			yyVAL.node = Node("BooleanNot").append(yyDollar[2].node)
		}
	case 332:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:988
		{
			yyVAL.node = Node("BitwiseNot").append(yyDollar[2].node)
		}
	case 333:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:989
		{
			yyVAL.node = Node("Identical").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 334:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:990
		{
			yyVAL.node = Node("NotIdentical").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 335:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:991
		{
			yyVAL.node = Node("Equal").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 336:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:992
		{
			yyVAL.node = Node("NotEqual").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 337:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:993
		{
			yyVAL.node = Node("Spaceship").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 338:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:994
		{
			yyVAL.node = Node("Smaller").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 339:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:995
		{
			yyVAL.node = Node("SmallerOrEqual").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 340:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:996
		{
			yyVAL.node = Node("Greater").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 341:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:997
		{
			yyVAL.node = Node("GreaterOrEqual").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 342:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:998
		{
			yyVAL.node = Node("InstanceOf").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 343:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:999
		{
			yyVAL.node = yyDollar[2].node
		}
	case 344:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1000
		{
			yyVAL.node = yyDollar[1].node
		}
	case 345:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:1001
		{
			yyVAL.node = Node("Ternary").append(yyDollar[1].node).append(yyDollar[3].node).append(yyDollar[5].node)
		}
	case 346:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:1002
		{
			yyVAL.node = Node("Ternary").append(yyDollar[1].node).append(yyDollar[4].node)
		}
	case 347:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1003
		{
			yyVAL.node = Node("Coalesce").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 348:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1004
		{
			yyVAL.node = yyDollar[1].node
		}
	case 349:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:1005
		{
			yyVAL.node = Node("CastInt").append(yyDollar[2].node)
		}
	case 350:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:1006
		{
			yyVAL.node = Node("CastDouble").append(yyDollar[2].node)
		}
	case 351:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:1007
		{
			yyVAL.node = Node("CastString").append(yyDollar[2].node)
		}
	case 352:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:1008
		{
			yyVAL.node = Node("CastArray").append(yyDollar[2].node)
		}
	case 353:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:1009
		{
			yyVAL.node = Node("CastObject").append(yyDollar[2].node)
		}
	case 354:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:1010
		{
			yyVAL.node = Node("CastBool").append(yyDollar[2].node)
		}
	case 355:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:1011
		{
			yyVAL.node = Node("CastUnset").append(yyDollar[2].node)
		}
	case 356:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:1012
		{
			yyVAL.node = Node("Exit").append(yyDollar[2].node)
		}
	case 357:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:1013
		{
			yyVAL.node = Node("Silence").append(yyDollar[2].node)
		}
	case 358:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1014
		{
			yyVAL.node = yyDollar[1].node
		}
	case 359:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1015
		{
			yyVAL.node = Node("ShellExec").append(yyDollar[2].node)
		}
	case 360:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:1016
		{
			yyVAL.node = Node("Print").append(yyDollar[2].node)
		}
	case 361:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1017
		{
			yyVAL.node = Node("Yield")
		}
	case 362:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:1018
		{
			yyVAL.node = Node("Yield").append(yyDollar[2].node)
		}
	case 363:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:1019
		{
			yyVAL.node = Node("Yield").append(yyDollar[2].node).append(yyDollar[4].node)
		}
	case 364:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:1020
		{
			yyVAL.node = Node("YieldFrom").append(yyDollar[2].node)
		}
	case 365:
		yyDollar = yyS[yypt-10 : yypt+1]
		//line parser.y:1022
		{
			yyVAL.node = Node("Closure").
				attribute("returns_ref", yyDollar[2].value).
				append(yyDollar[4].node).
				append(yyDollar[6].node).
				append(yyDollar[7].node).
				append(yyDollar[9].node)
		}
	case 366:
		yyDollar = yyS[yypt-11 : yypt+1]
		//line parser.y:1031
		{
			yyVAL.node = Node("StaticClosure").
				attribute("returns_ref", yyDollar[3].value).
				append(yyDollar[5].node).
				append(yyDollar[7].node).
				append(yyDollar[8].node).
				append(yyDollar[10].node)
		}
	case 367:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:1042
		{
			yyVAL.value = "false"
		}
	case 368:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1043
		{
			yyVAL.value = "true"
		}
	case 369:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:1047
		{
			yyVAL.node = Node("")
		}
	case 370:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:1048
		{
			yyVAL.node = yyDollar[3].node
		}
	case 371:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1052
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 372:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1053
		{
			yyVAL.node = Node("ClosureUses").append(yyDollar[1].node)
		}
	case 373:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1057
		{
			yyVAL.node = Node("Variable").attribute("value", yyDollar[1].token)
		}
	case 374:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:1058
		{
			yyVAL.node = Node("Variable").attribute("value", yyDollar[2].token).attribute("ref", "true")
		}
	case 375:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:1062
		{
			yyVAL.node = Node("FunctionCall").append(yyDollar[1].node).append(yyDollar[2].node)
		}
	case 376:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:1064
		{
			yyVAL.node = Node("StaticCall").append(yyDollar[1].node).append(yyDollar[3].node).append(yyDollar[4].node)
		}
	case 377:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:1066
		{
			yyVAL.node = Node("StaticCall").append(yyDollar[1].node).append(yyDollar[3].node).append(yyDollar[4].node)
		}
	case 378:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:1067
		{
			yyVAL.node = Node("Call").append(yyDollar[1].node).append(yyDollar[2].node)
		}
	case 379:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1071
		{
			yyVAL.node = Node("Static")
		}
	case 380:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1072
		{
			yyVAL.node = yyDollar[1].node
		}
	case 381:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1076
		{
			yyVAL.node = yyDollar[1].node
		}
	case 382:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1077
		{
			yyVAL.node = yyDollar[1].node
		}
	case 383:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:1081
		{
			yyVAL.node = Node("")
		}
	case 384:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1082
		{
			yyVAL.node = yyDollar[2].node
		}
	case 385:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:1086
		{
			yyVAL.node = Node("EmptyBackticks")
		}
	case 386:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1087
		{
			yyVAL.node = Node("String").attribute("value", yyDollar[1].token)
		}
	case 387:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1088
		{
			yyVAL.node = yyDollar[1].node
		}
	case 388:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:1092
		{
			yyVAL.node = Node("ArgumentList")
		}
	case 389:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1093
		{
			yyVAL.node = yyDollar[1].node
		}
	case 390:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:1097
		{
			yyVAL.node = yyDollar[3].node
		}
	case 391:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1098
		{
			yyVAL.node = yyDollar[2].node
		}
	case 392:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1099
		{
			yyVAL.node = Node("String").attribute("value", yyDollar[1].token)
		}
	case 393:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1103
		{
			yyVAL.node = Node("Scalar").append(Node("Lnumber").attribute("value", yyDollar[1].token))
		}
	case 394:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1104
		{
			yyVAL.node = Node("Scalar").append(Node("Dnumber").attribute("value", yyDollar[1].token))
		}
	case 395:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1105
		{
			yyVAL.node = Node("Scalar").append(Node("__LINE__"))
		}
	case 396:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1106
		{
			yyVAL.node = Node("Scalar").append(Node("__FILE__"))
		}
	case 397:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1107
		{
			yyVAL.node = Node("Scalar").append(Node("__DIR__"))
		}
	case 398:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1108
		{
			yyVAL.node = Node("Scalar").append(Node("__TRAIT__"))
		}
	case 399:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1109
		{
			yyVAL.node = Node("Scalar").append(Node("__METHOD__"))
		}
	case 400:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1110
		{
			yyVAL.node = Node("Scalar").append(Node("__FUNCTION__"))
		}
	case 401:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1111
		{
			yyVAL.node = Node("Scalar").append(Node("__NAMESPACE__"))
		}
	case 402:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1112
		{
			yyVAL.node = Node("Scalar").append(Node("__CLASS__"))
		}
	case 403:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1114
		{
			yyVAL.node = Node("Scalar").append(Node("Heredoc").attribute("value", yyDollar[2].token))
		}
	case 404:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:1116
		{
			yyVAL.node = Node("Scalar").append(Node("Heredoc"))
		}
	case 405:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1117
		{
			yyVAL.node = yyDollar[2].node
		}
	case 406:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1118
		{
			yyVAL.node = yyDollar[2].node
		}
	case 407:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1119
		{
			yyVAL.node = yyDollar[1].node
		}
	case 408:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1120
		{
			yyVAL.node = yyDollar[1].node
		}
	case 409:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1124
		{
			yyVAL.node = Node("Const").append(yyDollar[1].node)
		}
	case 410:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1125
		{
			yyVAL.node = Node("Const").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 411:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1127
		{
			yyVAL.node = Node("Const").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 412:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1131
		{
			yyVAL.node = yyDollar[1].node
		}
	case 413:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1132
		{
			yyVAL.node = yyDollar[1].node
		}
	case 414:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:1136
		{
			yyVAL.node = Node("")
		}
	case 415:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1137
		{
			yyVAL.node = yyDollar[1].node
		}
	case 416:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1141
		{
			yyVAL.node = yyDollar[1].node
		}
	case 417:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1145
		{
			yyVAL.node = yyDollar[1].node
		}
	case 418:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1146
		{
			yyVAL.node = yyDollar[2].node
		}
	case 419:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1147
		{
			yyVAL.node = yyDollar[1].node
		}
	case 420:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1151
		{
			yyVAL.node = yyDollar[1].node
		}
	case 421:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1152
		{
			yyVAL.node = yyDollar[2].node
		}
	case 422:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1153
		{
			yyVAL.node = yyDollar[1].node
		}
	case 423:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1157
		{
			yyVAL.node = yyDollar[1].node
		}
	case 424:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:1158
		{
			yyVAL.node = Node("Dim").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 425:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:1159
		{
			yyVAL.node = Node("Dim").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 426:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:1160
		{
			yyVAL.node = Node("Dim").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 427:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:1162
		{
			yyVAL.node = Node("MethodCall").append(yyDollar[1].node).append(yyDollar[3].node).append(yyDollar[4].node)
		}
	case 428:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1163
		{
			yyVAL.node = yyDollar[1].node
		}
	case 429:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1167
		{
			yyVAL.node = yyDollar[1].node
		}
	case 430:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1168
		{
			yyVAL.node = yyDollar[1].node
		}
	case 431:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1169
		{
			yyVAL.node = Node("Property").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 432:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1173
		{
			yyVAL.node = Node("Variable").attribute("name", yyDollar[1].token)
		}
	case 433:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:1174
		{
			yyVAL.node = Node("Variable").append(yyDollar[3].node)
		}
	case 434:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:1175
		{
			yyVAL.node = Node("Variable").append(yyDollar[2].node)
		}
	case 435:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1180
		{
			yyVAL.node = Node("StaticProp").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 436:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1182
		{
			yyVAL.node = Node("StaticProp").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 437:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1186
		{
			yyVAL.node = yyDollar[1].node
		}
	case 438:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:1187
		{
			yyVAL.node = Node("Dim").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 439:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:1188
		{
			yyVAL.node = Node("Dim").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 440:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1189
		{
			yyVAL.node = Node("Property").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 441:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1191
		{
			yyVAL.node = Node("StaticProperty").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 442:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1193
		{
			yyVAL.node = Node("StaticProperty").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 443:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1197
		{
			yyVAL.node = yyDollar[1].node
		}
	case 444:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1198
		{
			yyVAL.node = yyDollar[2].node
		}
	case 445:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1199
		{
			yyVAL.node = yyDollar[1].node
		}
	case 446:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1203
		{
			yyVAL.node = Node("PropertyName").attribute("value", yyDollar[1].token)
		}
	case 447:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1204
		{
			yyVAL.node = yyDollar[2].node
		}
	case 448:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1205
		{
			yyVAL.node = yyDollar[1].node
		}
	case 449:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1209
		{ /* TODO: allow single trailing comma */
			yyVAL.node = yyDollar[1].node
		}
	case 450:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:1213
		{
			yyVAL.node = Node("")
		}
	case 451:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1214
		{
			yyVAL.node = yyDollar[1].node
		}
	case 452:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1219
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 453:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1220
		{
			yyVAL.node = Node("ArrayPairList").append(yyDollar[1].node)
		}
	case 454:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1224
		{
			yyVAL.node = Node("ArrayElement").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 455:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1225
		{
			yyVAL.node = Node("ArrayElement").append(yyDollar[1].node)
		}
	case 456:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:1226
		{
			yyVAL.node = Node("ArrayElement").append(yyDollar[1].node).append(Node("Ref").append(yyDollar[4].node))
		}
	case 457:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:1227
		{
			yyVAL.node = Node("ArrayElement").append(Node("Ref").append(yyDollar[2].node))
		}
	case 458:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:1229
		{
			yyVAL.node = Node("ArrayElement").
				append(yyDollar[1].node).
				append(Node("ArrayList").append(yyDollar[5].node))
		}
	case 459:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:1235
		{
			yyVAL.node = Node("ArrayElement").
				append(Node("ArrayList").append(yyDollar[3].node))
		}
	case 460:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:1242
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[2].node)
		}
	case 461:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:1243
		{
			yyVAL.node = yyDollar[1].node.append(Node("String").attribute("value", yyDollar[2].token))
		}
	case 462:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1244
		{
			yyVAL.node = Node("EncapsList").append(yyDollar[1].node)
		}
	case 463:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:1245
		{
			yyVAL.node = Node("EncapsList").append(Node("String").attribute("value", yyDollar[1].token)).append(yyDollar[2].node)
		}
	case 464:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1249
		{
			yyVAL.node = Node("Variable").attribute("value", yyDollar[1].token)
		}
	case 465:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:1250
		{
			yyVAL.node = Node("Variable").attribute("value", yyDollar[1].token).append(Node("offset").append(yyDollar[3].node))
		}
	case 466:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1251
		{
			yyVAL.node = Node("Variable").attribute("value", yyDollar[1].token).append(Node("property").attribute("value", yyDollar[3].token))
		}
	case 467:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1252
		{
			yyVAL.node = Node("Variable").append(Node("expr").append(yyDollar[2].node))
		}
	case 468:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1253
		{
			yyVAL.node = Node("Variable").attribute("value", yyDollar[2].token)
		}
	case 469:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:1255
		{
			yyVAL.node = Node("Variable").attribute("value", yyDollar[2].token).append(Node("offset").append(yyDollar[4].node))
		}
	case 470:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1256
		{
			yyVAL.node = yyDollar[2].node
		}
	case 471:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1259
		{
			yyVAL.node = Node("OffsetString").attribute("value", yyDollar[1].token)
		}
	case 472:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1260
		{
			yyVAL.node = Node("OffsetNumString").attribute("value", yyDollar[1].token)
		}
	case 473:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:1261
		{
			yyVAL.node = Node("OffsetNegateNumString").attribute("value", yyDollar[2].token)
		}
	case 474:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1262
		{
			yyVAL.node = Node("OffsetVariable").attribute("value", yyDollar[1].token)
		}
	case 475:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:1266
		{
			yyVAL.node = yyDollar[3].node
		}
	case 476:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:1267
		{
			yyVAL.node = Node("Empty").append(yyDollar[3].node)
		}
	case 477:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:1268
		{
			yyVAL.node = Node("Include").append(yyDollar[2].node)
		}
	case 478:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:1269
		{
			yyVAL.node = Node("IncludeOnce").append(yyDollar[2].node)
		}
	case 479:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:1270
		{
			yyVAL.node = Node("Eval").append(yyDollar[3].node)
		}
	case 480:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:1271
		{
			yyVAL.node = Node("Require").append(yyDollar[2].node)
		}
	case 481:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:1272
		{
			yyVAL.node = Node("RequireOnce").append(yyDollar[2].node)
		}
	case 482:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1276
		{
			yyVAL.node = yyDollar[1].node
		}
	case 483:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1277
		{
			yyVAL.node = Node("AndIsset").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 484:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1281
		{
			yyVAL.node = Node("Isset").append(yyDollar[1].node)
		}
	}
	goto yystack /* stack new state and value */
}
